@@ -462,10 +462,9 @@ class Action(Parametrizable,Permittable):
       
     def __get__(self, instance, owner):
         """
-        Getting an Action instance of an *Actor* (which is a class) 
-        will return the 
+        When a model has an action "foo", then getting an attribute
+        "foo" of a model instance will return an :class:`InstanceAction`.
         """
-        #~ print "__get__ %r / %r / %r" % (self, instance, owner)
         if instance is None:
             return self
         return InstanceAction(self,instance.get_default_table(),instance,owner)
@@ -597,7 +596,10 @@ class Action(Parametrizable,Permittable):
     def get_action_permission(self,ar,obj,state):
         """
         Derived Action classes may override this to add vetos.
-        E.g. DispatchAction is not available for a User with empty partner.
+        E.g. DispatchAction is not available for a User with empty 
+        partner.
+        Or MoveUp action of a Sequenced is not available on the first 
+        row of given `ar`.
         """
         return True
         
@@ -691,7 +693,7 @@ class RedirectAction(Action):
 
 class GridEdit(TableAction):
     
-    #~ debug_permissions = 20130429 # Melanie doesn't see :menulabel:`Explorer --> Courses`
+    #~ debug_permissions = 20130704 
   
     use_param_panel = True
     show_in_workflow = False
@@ -1029,16 +1031,19 @@ class NotifyingAction(RowAction):
         
     def action_param_defaults(self,ar,obj,**kw):
         kw = super(NotifyingAction,self).action_param_defaults(ar,obj,**kw)
-        s = self.get_notify_subject(ar,obj)
-        if s is not None: kw.update(notify_subject=s)
-        s = self.get_notify_body(ar,obj)
-        if s is not None: kw.update(notify_body=s)
+        if obj is not None:
+            s = self.get_notify_subject(ar,obj)
+            if s is not None: kw.update(notify_subject=s)
+            s = self.get_notify_body(ar,obj)
+            if s is not None: kw.update(notify_body=s)
         return kw
         
     def run_from_ui(self,obj,ar,**kw):
         kw.update(message=ar.action_param_values.notify_subject)
         kw.update(alert=True)
-        kw = super(NotifyingAction,self).run_from_ui(obj,ar,**kw)
+        kw.update(refresh=True)
+        kw.update(success=True)
+        #~ kw = super(NotifyingAction,self).run_from_ui(obj,ar,**kw)
         self.add_system_note(ar,obj)
         return kw
     
