@@ -79,8 +79,8 @@ def register_actor(a):
     #~ actors_dict[a.actor_id] = a
     actors_list.append(a)
     return a
-  
-    
+
+
 def get_default_required(**kw):
     #~ if not kw.has_key('auth'):
         #~ kw.update(auth=True)
@@ -393,6 +393,17 @@ class Actor(actions.Parametrizable):
     Otherwise it will be set to `False` if the Actor 
     is a Table and has a `get_data_rows` method.
     
+    Note that this attribute is not inherited to subclasses.
+    (TODO: explain why... because at least for 
+    `lino_faggio.models.InvoicingsByEnrolment` it is disturbing 
+    to not inherit it.    
+    Has to do with :class:`DistByBudget <lino_welfare.modellib.debts.models.DistByBudget>` 
+    which defines its own `get_data_rows` but inherits from 
+    :class:`EntriesByBudget
+    <lino_welfare.modellib.debts.models.EntriesByBudget>` 
+    which has no `get_data_rows`.)
+    
+    
     The :class:`lino.models.Changes` table is an example where this is being used: 
     nobody should ever edit something in the table of Changes. 
     The user interface uses this to generate optimized JS code for this case.
@@ -585,6 +596,17 @@ class Actor(actions.Parametrizable):
         #~ return self.__dict__.get(hname,False)
         return self.__dict__.get(_handle_attr_name,False)
         
+    @classmethod
+    def clear_handle(self):
+        """
+        When an actor has dynamic columns which depend on database 
+        content, then its layout handle may not persist between 
+        different Django test cases because a handle from a first
+        test case may refer to elements which no longer exist in a 
+        second test case.
+        """
+        setattr(self,_handle_attr_name,None)
+        
     @classmethod
     def on_analyze(self,site):
         pass
@@ -654,13 +676,18 @@ class Actor(actions.Parametrizable):
         #~ classDict = cls.__dict__
         
         #~ dt = classDict.get('detail_template',None)
-        dt = getattr(cls,'detail_template',None)
-        if dt is not None:
-            raise Exception("Please rename detail_template to detail_layout")
+        #~ dt = getattr(cls,'detail_template',None)
+        #~ if dt is not None:
+            #~ raise Exception("Please rename detail_template to detail_layout")
             #~ if dl is not None:
                 #~ raise Exception("%r has both detail_template and detail_layout" % cls)
             #~ dl = dt
             
+        master = getattr(cls,'master',None)
+        if master is not None:
+            cls.master = resolve_model(master)
+                
+                
         #~ dl = classDict.get('detail_layout',None)
         dl = getattr(cls,'detail_layout',None)
         if dl is not None:
@@ -1274,3 +1301,15 @@ class Actor(actions.Parametrizable):
         Don't worry if you don't understand. 
         """
         return []
+
+
+    @classmethod
+    def get_choices_text(self,obj,request,field):
+        """
+        Return the text to be displayed in a combo box 
+        for the field `field` of this actor to represent 
+        the choice `obj`.
+        Override this if you want a customized representation.
+        For example :class:`lino_faggio.models.InvoiceItems`
+        """
+        return obj.get_choices_text(request,self,field)
