@@ -84,6 +84,7 @@ URL_PARAM_LIMIT = 'limit'
 URL_PARAM_WIDTHS = 'cw'
 URL_PARAM_HIDDENS = 'ch'
 URL_PARAM_COLUMNS = 'ci'
+URL_PARAM_SHOW_PARAMS_PANEL = 'sp'
 #~ TEST = 'name'
 
 URL_PARAMS = [
@@ -99,6 +100,7 @@ URL_PARAMS = [
   'URL_PARAM_LIMIT',
   'URL_PARAM_TAB',
   'URL_PARAM_REQUESTING_PANEL',
+  'URL_PARAM_SHOW_PARAMS_PANEL',
   #~ 'URL_PARAM_EXPAND',
   #~ 'URL_PARAM_EUSER',
   'URL_PARAM_SUBST_USER',
