@@ -62,7 +62,6 @@ from lino.core import fields
 from lino.core import actions
 from lino.core.model import Model
 from djangosite.dbutils import obj2str
-from lino.utils.config import load_config_files, Configured
 #~ from lino.core import datalinks
 #~ from lino.core import boolean_texts
 from lino.core import actors
@@ -669,7 +668,7 @@ class Table(AbstractTable):
                             break
                 if master_model is None:
                     raise Exception("%s : no master for master_key %r in %s" % (
-                        self,self.master_key,self.model.__name__))
+                        self,self.master_key,self.model))
                 self.master = master_model
                 #~ self.fk = fk
                 self.master_field = fk
@@ -812,9 +811,8 @@ class Table(AbstractTable):
     @classmethod
     def get_queryset(self):
         """
-        Return an iterable over the items processed by this report.
-        Override this to use e.g. select_related()
-        or to return a list.
+        Return an iterable over the items processed by this table.
+        Override this to use e.g. select_related() or to return a list.
         """
         return self.model.objects.all()
       
