@@ -195,6 +195,8 @@ class FakeField(object):
     help_text = None
     preferred_width = 30
     preferred_height = 3
+    max_digits = None
+    decimal_places = None
     
     def is_enabled(self,lh):
         """
@@ -226,6 +228,8 @@ class RemoteField(FakeField):
         self.rel = self.field.rel
         self.verbose_name = fld.verbose_name
         self.max_length = getattr(fld,'max_length',None)
+        self.max_digits = getattr(fld,'max_digits',None)
+        self.decimal_places = getattr(fld,'decimal_places',None)
         #~ print 20120424, self.name
         #~ settings.SITE.register_virtual_field(self)
         
@@ -770,9 +774,45 @@ class GenericForeignKey(generic.GenericForeignKey):
 
 
 
+class CharField(models.CharField):
+    """
+    
+    An extension around Django's `models.CharField`.
+    
+    Adds two keywords `mask_re` and
+    `strip_chars_re` which, when using the ExtJS ui, 
+    will be rendered as the 
+    `maskRe` and `stripCharsRe` config options 
+    of 
+    `TextField` 
+    as described in the 
+    `ExtJS documentation 
+    <http://docs.sencha.com/extjs/3.4.0/#!/api/Ext.form.TextField>`__,
+    converting naming conventions as follows:
+    
+    =============== ============ ==========================
+    regex           regex        A JavaScript RegExp object to be tested against the field value during validation (defaults to null). If the test fails, the field will be marked invalid using regexText.
+    mask_re         maskRe       An input mask regular expression that will be used to filter keystrokes that do not match (defaults to null). The maskRe will not operate on any paste events.
+    strip_chars_re  stripCharsRe A JavaScript RegExp object used to strip unwanted content from the value before validation (defaults to null).
+    =============== ============ ==========================
+    
+    
+    Example usage:
+    
+      belgian_phone_no = dd.CharField(max_length=15,strip_chars_re='')
+    
+    
+    """
+    
+    def __init__(self,*args,**kw):
+        self.strip_chars_re = kw.pop('strip_chars_re',None)
+        self.mask_re = kw.pop('mask_re',None)
+        self.regex = kw.pop('regex',None)
+        models.CharField.__init__(self,*args,**kw)
        
   
-class QuantityField(models.CharField):
+class QuantityField(CharField):
+#~ class QuantityField(models.CharField):
 #~ class QuantityField(models.DecimalField):
 #~ class QuantityField(models.Field):
     """
@@ -803,10 +843,31 @@ class QuantityField(models.CharField):
         #~ return "CharField"
         
     def to_python(self, value):
+        """
+        
+        Excerpt from `Django doc 
+        <https://docs.djangoproject.com/en/dev/howto/custom-model-fields/#django.db.models.Field.to_python>`__:
+        
+            As a general rule, the method should deal gracefully with any of the following arguments:
+
+            - An instance of the correct type (e.g., Hand in our ongoing example).
+            - A string (e.g., from a deserializer).
+            - Whatever the database returns for the column type you’re using.
+            
+        I'd add "Any value specified for this field when instantiating a model."
+       
+        >>> to_python(None)
+        >>> to_python(30)
+        >>> to_python(30L)
+        >>> to_python('')
+        >>> to_python(Decimal(0))
+        """
         if isinstance(value,Decimal):
             return value
         if value:
-            return quantities.parse(value)
+            if isinstance(value,basestring):
+                return quantities.parse(value)
+            return Decimal(value)
         return None
         
     #~ def get_db_prep_save(self, value, connection):
@@ -838,11 +899,6 @@ Uncomplete dates are allowed, e.g.
 "%(ex1)s" means "some day in 1980", 
 "%(ex2)s" means "in July 1980"
 or "%(ex3)s" means "on a 23th of July".""") % msgkw)
-        #~ kw.setdefault('help_text',u"""\
-#~ Unkomplette Datumsangaben sind erlaubt, z.B. 
-#~ "%(ex1)s" heißt "irgendwann im Jahr 1980", 
-#~ "%(ex2)s" heißt "im Juli 1980"
-#~ oder "%(ex3)s" heißt "an einem 23. Juli".""")
         models.CharField.__init__(self,*args,**kw)
       
     #~ def get_internal_type(self):
@@ -881,6 +937,8 @@ class DummyField(object):
     def set_attributes_from_name(self,k):
         pass
 
+      
+    
 class RecurrenceField(models.CharField):
     """
     Deserves more documentation.
@@ -931,8 +989,9 @@ def get_data_elem(model,name):
                     #~ print '20130422 %s --> %r', fld.name,obj
                     return obj
                 except Exception,e:
-                    logger.exception(e)
-                    return str(e)
+                    if False: # only for debugging
+                        logger.exception(e)
+                        return str(e) 
                     return None
             return RemoteField(func,name,fld)
     
@@ -1005,3 +1064,16 @@ def ForeignKey(othermodel,*args,**kw):
             return DummyField(othermodel,*args,**kw)
     return models.ForeignKey(othermodel,*args,**kw)
     
+
+class ImportedFields(object):
+    """
+    Utility mixin to easily declare "imported fields"
+    """
+    _imported_fields = set()
+    
+    @classmethod
+    def declare_imported_fields(cls,names):
+        cls._imported_fields = cls._imported_fields | set(fields_list(cls,names))
+        #~ logger.info('20120801 %s.declare_imported_fields() --> %s' % (
+            #~ cls,cls._imported_fields))
+        
