@@ -56,7 +56,7 @@ from lino.core import actors
 from lino.core import dbtables
 from lino.utils import class_dict_items
     
-from lino.utils.config import load_config_files, find_config_file
+#~ from lino.utils.config import load_config_files, find_config_file
 from lino.utils import choosers
 #~ from lino.utils import codetime
 from lino.utils import curry
@@ -83,6 +83,11 @@ def set_default_verbose_name(f):
     if f.verbose_name == f.name.replace('_', ' '):
         f.verbose_name = f.rel.to._meta.verbose_name
 
+#~ def shutdown_site(self):
+    #~ models_list = models.get_models(include_auto_created=True)
+    #~ for m in models_list:
+        #~ ...
+    
 def startup_site(self):
     """
     This is the code that runs when you call :meth:`lino.Site.startup`.
@@ -281,9 +286,6 @@ def startup_site(self):
 
     self.resolve_virtual_fields()
     
-    from lino.ui.ui import ExtUI
-    self.ui = ExtUI(self)
-    
 class DisableDeleteHandler():
     """
     Used to find out whether a known object can be deleted or not.
