@@ -27,6 +27,8 @@ See also:
 
 '''
 
+from __future__ import unicode_literals
+
 import logging
 logger = logging.getLogger(__name__)
 
@@ -322,6 +324,8 @@ class LayoutHandle:
         #~ setattr(self,name,e)
         self._names[name] = e
         #~ self.setup_element(e)
+        #~ if name == 'invoiceable':
+            #~ logger.info("20130612 create_element() --> %r", e)
         return e
         
     #~ def splitdesc(self,picture,**kw):
@@ -497,8 +501,8 @@ In %s, updating attribute %r:
            raise Exception("name may not contain any newline") 
         if ' ' in name:
            raise Exception("name may not contain any whitespace") 
-        if getattr(self,name,None) is not None:
-           raise Exception("name %r already defined in %s" % (name,self)) 
+        #~ if getattr(self,name,None) is not None:
+           #~ raise Exception("name %r already defined in %s" % (name,self)) 
         self._add_panel(name,tpl,label,options)
         
     #~ @classmethod    
@@ -935,7 +939,7 @@ def create_field_element(lh,field,**kw):
     #~ e = lh.main_class.field2elem(lh,field,**kw)
     from lino.ui import elems as ext_elems
     e = ext_elems.field2elem(lh,field,**kw)
-    assert e.field is not None,"e.field is None for %s.%s" % (lh.layout,name)
+    assert e.field is not None,"e.field is None for %s.%s" % (lh.layout,kw)
     lh.add_store_field(e.field)
     return e
     #return FieldElement(field,**kw)
