@@ -160,11 +160,13 @@ class Model(models.Model):
         
         
     
-    def get_choices_text(self,request,rpt,field):
+    def get_choices_text(self,request,actor,field):
         """
         Return the text to be displayed when an instance of this model 
         is being used as a choice in a combobox (i.e. by ForeignKey fields 
         pointing to this model).
+        `request` is the web request,
+        `actor` is the requesting actor.
         Default is to simply return `unicode(self)`.
         One usage example is :class:`lino.modlib.countries.models.City`.
         """
@@ -180,7 +182,7 @@ class Model(models.Model):
         """
         return self._lino_ddh.disable_delete_on_object(self)
         
-    @classmethod # classmethod since 20130422
+    @classmethod 
     def get_default_table(self):
         return self._lino_default_table
         
