@@ -245,7 +245,7 @@ class BaseRequest(object):
         msg.send()
         logger.info("System note '%s' from %s has been sent to %s",subject,sender,recipients)
         
-    def spawn(self,spec,**kw):
+    def spawn(self,spec,language=None,**kw):
         """
         Create a new ActionRequest, taking an "action specificator" 
         and using default values from this one (via :meth:setup_from`).
@@ -263,6 +263,9 @@ class BaseRequest(object):
             #~ print 20130425, __file__, mi.bound_action
             spec = mi.bound_action.request(**kw)
         spec.setup_from(self)
+        if language:
+            spec.set_language(language)
+        
         #~ ar.user = self.user
         #~ ar.subst_user = self.subst_user
         #~ ar.renderer = self.renderer
@@ -355,6 +358,10 @@ class ActionRequest(BaseRequest):
         if self.actor.parameters is not None:
             pv = self.actor.param_defaults(self)
             
+            for k in pv.keys():
+                if not k in self.actor.parameters:
+                    raise Exception("%s.param_defaults() returned invalid keyword %r" % (self.actor,k))
+            
             """
             New since 20120913.
             E.g. newcomers.Newcomers is a simple pcsw.Clients with known_values=dict(client_state=newcomer)
@@ -363,6 +370,7 @@ class ActionRequest(BaseRequest):
             for k,v in self.known_values.items():
                 if pv.has_key(k):
                     pv[k] = v
+            
             """
             New since 20120914.
             MyClientsByGroup has a known group, this 
@@ -372,20 +380,24 @@ class ActionRequest(BaseRequest):
             if self.actor.master_key is not None:
                 if pv.has_key(self.actor.master_key):
                     pv[self.actor.master_key] = self.master_instance
+                    
+            #~ logger.info("20130721 a core/requests.py param_values is %r",pv)
                 
             if param_values is None:
                 if request is not None: # 20121025
                     #~ pv.update(self.ui.parse_params(self.ah,request))
                     #~ pv.update(self.ah.store.parse_params(request))
                     pv.update(self.actor.params_layout.params_store.parse_params(request))
-                    
-            if param_values is not None:
+                    #~ logger.info("20130721 b core/requests.py param_values is %r",pv)
+            else:
                 for k in param_values.keys(): 
                     if not pv.has_key(k):
                         raise Exception("Invalid key '%s' in param_values of %s request (possible keys are %s)" % (k,actor,pv.keys()))
                 pv.update(param_values)
+                #~ logger.info("20130721 c core/requests.py param_values is %r",pv)
                 
             self.param_values = AttrDict(**pv)
+            #~ logger.info("20130721 d core/requests.py param_values is %r",pv)
             
         #~ print 20130121, __file__, self.bound_action.action, self.bound_action.action.parameters
         
@@ -500,6 +512,7 @@ class ActionRequest(BaseRequest):
             #~ kw.update(param_values=self.ah.store.pv2dict(ui,self.param_values))
             #~ lh = self.actor.params_layout.get_layout_handle(ui)
             kw.update(param_values=self.actor.params_layout.params_store.pv2dict(ui,self.param_values))
+            
         bp = kw.setdefault('base_params',{})
         if self.subst_user is not None:
             #~ bp[ext_requests.URL_PARAM_SUBST_USER] = self.subst_user.username
