@@ -76,8 +76,6 @@ from lino.core.model import Model
 from lino.core.requests import ActionRequest
 
 from lino.ui import base
-from lino.utils.config import Configured, load_config_files
-from lino.utils.config import find_config_file
 
 from lino.utils.appy_pod import Renderer
 
@@ -87,10 +85,13 @@ class InvalidRequest(Exception):
 
 from lino.utils.xmlgen.html import RstTable
 
-MAX_ROW_COUNT = 300
+MAX_ROW_COUNT = 900
 
+if False: # 20130710
 
-class GridConfig(Configured):
+  from lino.utils.config import Configured
+  
+  class GridConfig(Configured):
   
     def __init__(self,report,data,*args,**kw):
         self.report = report
@@ -226,9 +227,9 @@ class TableRequest(ActionRequest):
             try:
                 rows = self.actor.get_data_rows(self)
                 for row in rows:
-                    if len(l) > 300:
-                        raise Exception("20120521 More than 300 items in %s" % 
-                            unicode(rows))
+                    #~ if len(l) > 300:
+                        #~ raise Exception("20120521 More than 300 items in %s" % 
+                            #~ unicode(rows))
                     group = self.actor.group_from_row(row)
                     group.process_row(l,row)
             except Warning,e:
@@ -522,6 +523,8 @@ class TableRequest(ActionRequest):
         
     def appy_render(ar,target_file):
         
+        from lino.utils.config import find_config_file
+        
         if ar.get_total_count() > MAX_ROW_COUNT:
             raise Exception(_("List contains more than %d rows") % MAX_ROW_COUNT)
     
@@ -870,8 +873,9 @@ class AbstractTable(actors.Actor):
         #~ if self.default_action is None:
             #~ self.default_action = actions.GridEdit()
     
-        if self.get_data_rows is not None:
-            self.show_detail_navigator = False
+        #~ 20130714 navinfo now also works on lists
+        #~ if self.get_data_rows is not None:
+            #~ self.show_detail_navigator = False
             
         """
         :class:`lino_welfare.modellib.debts.models.DistByBudget` 
@@ -962,6 +966,7 @@ class AbstractTable(actors.Actor):
         
     @classmethod
     def save_grid_config(self,index,data):
+        raise Exception("20130710")
         if len(self.grid_configs) == 0:
             gc = GridConfig(self,data,'%s.gc' % self)
             self.grid_configs.append(gc)
@@ -1152,9 +1157,12 @@ class VentilatingTable(AbstractTable):
         
 
 
-@signals.receiver(signals.database_ready)
+from djangosite.signals import database_ready
+
+@signals.receiver(database_ready)
 def setup_ventilated_columns(sender,**kw):
-    for a in actors.actors_list:
-        if issubclass(a,AbstractTable):
-            a.setup_columns()
-    sender.resolve_virtual_fields()
+    if actors.actors_list is not None:
+        for a in actors.actors_list:
+            if issubclass(a,AbstractTable):
+                a.setup_columns()
+    settings.SITE.resolve_virtual_fields()
