@@ -33,6 +33,7 @@ Tables:
 
 Extended Fields:
 
+- :class:`CharField <fields.CharField>`
 - :class:`EnableChild <lino.utils.mti.EnableChild>`
 - :class:`NullCharField <lino.core.fields.NullCharField>`
 - :class:`IncompleteDateField <lino.core.fields.IncompleteDateField>`
@@ -79,52 +80,48 @@ Utilities:
   :func:`inrange_filter <djangosite.dbutils.inrange_filter>`
 - :func:`full_model_name <djangosite.dbutils.full_model_name>`
 - :func:`fields_list <lino.core.fields.fields_list>`
+- :func:`chooser <lino.utils.choosers.chooser>` 
+
+Inter-app relations:
+
 - :func:`resolve_field <lino.core.dbutils.resolve_field>`
 - :func:`resolve_model <north.dbutils.resolve_model>`
 - :func:`resolve_app <lino.core.dbutils.resolve_app>` 
-- :func:`chooser <lino.utils.choosers.chooser>` 
-- :func:`add_user_group` 
 - :func:`update_field <lino.core.inject.update_field>` 
 - :func:`inject_field <lino.core.inject.inject_field>` 
 - :func:`inject_quick_add_buttons <lino.core.inject.inject_quick_add_buttons>` 
 - :func:`models_by_base <djangosite.dbutils.models_by_base>` 
 
+Signals: 
 
-
-Signals:
-
-- :attr:`pre_startup <djangosite.signals.pre_startup>`
-- :attr:`post_startup <djangosite.signals.post_startup>`
-- :attr:`pre_analyze <lino.core.signals.pre_analyze>`
-- :attr:`post_analyze <lino.core.signals.post_analyze>`
-- :attr:`pre_merge <lino.core.signals.pre_merge>`
-- :attr:`pre_ui_create <lino.core.signals.pre_ui_create>`
-- :attr:`ChangeWatcher <lino.core.signals.ChangeWatcher>`
-- :attr:`pre_ui_update <lino.core.signals.pre_ui_update>`
-- :attr:`pre_ui_delete <lino.core.signals.pre_ui_delete>`
-- :attr:`database_connected <lino.core.signals.database_connected>`
-- :attr:`receiver <django.dispatch.receiver>` : the standard Django receiver decorator
-- (and many more)
+- See :ref:`lino.signals`
 
 Actions:
 
 - :class:`AuthorRowAction <lino.mixins.AuthorRowAction>`
 - :class:`RowAction <lino.core.actions.RowAction>`
 - :class:`AjaxAction <lino.core.actions.RowAction>`
-- :class:`ChangeStateAction <lino.core.changes.ChangeStateAction>`
+- :class:`ChangeStateAction <lino.core.workflows.ChangeStateAction>`
 - :class:`NotifyingAction <lino.core.actions.NotifyingAction>`
 - :class:`MergeAction <lino.core.merge.MergeAction>`
 
-Miscellaneous:
-
-- :class:`ChoiceList <lino.core.choicelists.ChoiceList>`
-- :class:`Workflow <lino.core.workflows.Workflow>`
-
-- :class:`Genders <lino.core.choicelists.Genders>`
+Permissions:
 
 - :class:`UserProfiles <lino.utils.auth.UserProfiles>`
 - :class:`UserGroups <lino.utils.auth.UserGroups>`
 - :class:`UserLevels <lino.utils.auth.UserLevels>`
+- :func:`add_user_group` 
+
+
+Workflows:
+
+- :class:`ChoiceList <lino.core.choicelists.ChoiceList>`
+- :class:`Workflow <lino.core.workflows.Workflow>`
+- :class:`State <lino.core.workflows.State>`
+
+Miscellaneous:
+
+- :class:`Genders <lino.core.choicelists.Genders>`
 
 
 """
@@ -183,12 +180,11 @@ from lino.core.actions import SubmitDetail, SubmitInsert
 from lino.core.choicelists import ChoiceList, Choice
 from lino.core.choicelists import Genders
 from lino.core.choicelists import YesNo
-from lino.core.workflows import Workflow, ChangeStateAction
-#~ from lino.core.changes import ChangeStateAction
+from lino.core.workflows import State, Workflow, ChangeStateAction
 from lino.core.actions import NotifyingAction
 
 
-from lino.core.fields import fields_list
+from lino.core.fields import fields_list, ImportedFields
 from lino.core.fields import DummyField
 from lino.core.fields import RecurrenceField
 from lino.core.fields import GenericForeignKey
@@ -209,6 +205,7 @@ from lino.core.fields import RequestField, requestfield
 from lino.core.fields import Constant, constant
 from lino.core.fields import ForeignKey
 from lino.core.fields import BabelTextField
+from lino.core.fields import CharField
 
 from lino.mixins import BabelNamed
 
@@ -237,7 +234,9 @@ from lino.core.layouts import ParamsLayout
 
 from lino.core.signals import pre_ui_create, pre_ui_delete, pre_ui_update, ChangeWatcher
 from lino.core.signals import database_connected
-from lino.core.signals import database_ready
+#~ from lino.core.signals import database_ready
+from djangosite.signals import database_ready
+
 from djangosite.signals import pre_startup, post_startup
 
 from lino.core.signals import pre_analyze
@@ -287,6 +286,7 @@ def add_user_group(name,label):
             g.text += " & " + unicode(label)
     
 from lino.core.actors import get_default_required as required
+Required = required
     
 class PseudoRequest:
     def __init__(self,username):
@@ -328,6 +328,5 @@ from lino.mixins.human import Human, Born, Genders
 
 #~ from lino.utils.screenshots import register_screenshot
 
-
-
+from django.utils.importlib import import_module
 
