@@ -299,9 +299,10 @@ class ExtRenderer(HtmlRenderer):
         #~ return None
 
     def instance_handler(self,ar,obj):
+        #~ if True: # obj.__class__.__name__ == 'Budget':
+            #~ raise Exception('20130610, %s' % obj.__class__.__name__)
         a = getattr(obj,'_detail_action',None)
         if a is None:
-            #~ a = obj.get_default_table(ar).get_url_action('detail_action')
             a = obj.get_default_table().detail_action
             #~ a = obj.__class__._lino_default_table.get_url_action('detail_action')
         if a is not None:
@@ -449,12 +450,14 @@ class ExtRenderer(HtmlRenderer):
             yield javascript(site.build_extjs_url('adapter/ext/ext-base-debug.js'))
             yield javascript(site.build_extjs_url('ext-all-debug.js'))
             if site.use_extensible:
-                yield javascript(site.build_media_url('extensible/extensible-all-debug.js'))
+                #~ yield javascript(site.build_media_url('extensible/extensible-all-debug.js'))
+                yield javascript(site.build_extensible_url('extensible-all-debug.js'))
         else:
             yield javascript(site.build_extjs_url('adapter/ext/ext-base.js'))
             yield javascript(site.build_extjs_url('ext-all.js'))
             if site.use_extensible:
-                yield javascript(site.build_media_url('extensible/extensible-all.js'))
+                #~ yield javascript(site.build_media_url('extensible/extensible-all.js'))
+                yield javascript(site.build_extensible_url('extensible-all.js'))
                 
         if translation.get_language() != 'en':
             yield javascript(site.build_extjs_url('src/locale/ext-lang-'+translation.get_language()+'.js'))
@@ -498,7 +501,7 @@ tinymce.init({
             
         if site.use_eid_jslib:
             yield javascript(site.build_media_url('eid-jslib/be_belgium_eid.js'))
-            yield javascript(site.build_media_url('/eid-jslib/hellerim_base64.js'))
+            yield javascript(site.build_media_url('eid-jslib/hellerim_base64.js'))
             
         #~ if site.use_bootstrap:
             #~ yield '<script src="//ajax.googleapis.com/ajax/libs/jquery/1.8.3/jquery.min.js"></script>'
@@ -581,80 +584,82 @@ tinymce.init({
         
         #~ yield "console.time('onReady');"
         
-        if request.user.profile.authenticated:
+        if settings.SITE.user_model is not None:
+
+            if request.user.profile.authenticated:
           
-            if request.subst_user:
-                #~ yield "Lino.subst_user = %s;" % py2js(request.subst_user.id)
-                yield "Lino.set_subst_user(%s,%s);" % (
-                    py2js(request.subst_user.id),
-                    py2js(unicode(request.subst_user)))
-                user_text = unicode(request.user) + " (" + _("as") + " " + unicode(request.subst_user) + ")"
+                if request.subst_user:
+                    #~ yield "Lino.subst_user = %s;" % py2js(request.subst_user.id)
+                    yield "Lino.set_subst_user(%s,%s);" % (
+                        py2js(request.subst_user.id),
+                        py2js(unicode(request.subst_user)))
+                    user_text = unicode(request.user) + " (" + _("as") + " " + unicode(request.subst_user) + ")"
+                else:
+                    #~ yield "Lino.subst_user = null;"
+                    yield "Lino.set_subst_user();"
+                    user_text = unicode(request.user) 
+                    
+                user = request.user
+                
+                yield "Lino.user = %s;" % py2js(dict(id=user.id,name=unicode(user)))
+                
+                if user.profile.level >= dd.UserLevels.admin:
+                    authorities = [(u.id,unicode(u)) 
+                        #~ for u in users.User.objects.exclude(profile=dd.UserProfiles.blank_item)] 20120829
+                        #~ for u in users.User.objects.filter(profile__isnull=False)]
+                        for u in users.User.objects.exclude(profile='').exclude(id=user.id)]
+                        #~ for u in users.User.objects.filter(profile__gte=dd.UserLevels.guest)]
+                else:
+                    authorities = [(a.user.id,unicode(a.user)) 
+                        for a in users.Authority.objects.filter(authorized=user)]
+                
+                #~ handler = self.ext_renderer.instance_handler(user)
+                #~ a = users.MySettings.get_url_action('default_action')
+                a = users.MySettings.default_action
+                handler = self.action_call(None,a,dict(record_id=user.pk))
+                handler = "function(){%s}" % handler
+                mysettings = dict(text=_("My settings"),handler=js_code(handler))
+                login_menu_items = [mysettings]
+                if len(authorities):
+                    #~ act_as = [
+                        #~ dict(text=unicode(u),handler=js_code("function(){Lino.set_subst_user(%s)}" % i)) 
+                            #~ for i,u in user.get_received_mandates()]
+                    act_as = [
+                        dict(text=t,handler=js_code("function(){Lino.set_subst_user(%s,%s)}" % (v,py2js(t)))) 
+                            for v,t in authorities]
+                            #~ for v,t in user.get_received_mandates()]
+                    act_as.insert(0,dict(
+                        text=_("Myself"),
+                        handler=js_code("function(){Lino.set_subst_user(null)}")))
+                    act_as = dict(text=_("Act as..."),menu=dict(items=act_as))
+                    
+                    login_menu_items.insert(0,act_as)
+                    #~ login_menu_items = [act_as,mysettings]
+                    
+                if site.remote_user_header is None:
+                    login_menu_items.append(dict(text=_("Log out"),handler=js_code('Lino.logout')))
+                    login_menu_items.append(dict(text=_("Change password"),handler=js_code('Lino.change_password')))
+                    login_menu_items.append(dict(text=_("Forgot password"),handler=js_code('Lino.forgot_password')))
+                
+                login_menu = dict(
+                    text=user_text,
+                    menu=dict(items=login_menu_items))
+                #~ else:
+                    #~ login_menu = dict(text=user_text,handler=js_code(handler))
+                    
+                #~ yield "Lino.login_menu = %s;" % py2js(login_menu)
+                #~ yield "Lino.main_menu = Lino.main_menu.concat(['->',Lino.login_menu]);"
+                yield "Lino.main_menu = Lino.main_menu.concat(['->',%s]);" % py2js(login_menu)
+                
             else:
-                #~ yield "Lino.subst_user = null;"
-                yield "Lino.set_subst_user();"
-                user_text = unicode(request.user) 
-                
-            user = request.user
-            
-            yield "Lino.user = %s;" % py2js(dict(id=user.id,name=unicode(user)))
-            
-            if user.profile.level >= dd.UserLevels.admin:
-                authorities = [(u.id,unicode(u)) 
-                    #~ for u in users.User.objects.exclude(profile=dd.UserProfiles.blank_item)] 20120829
-                    #~ for u in users.User.objects.filter(profile__isnull=False)]
-                    for u in users.User.objects.exclude(profile='').exclude(id=user.id)]
-                    #~ for u in users.User.objects.filter(profile__gte=dd.UserLevels.guest)]
-            else:
-                authorities = [(a.user.id,unicode(a.user)) 
-                    for a in users.Authority.objects.filter(authorized=user)]
-            
-            #~ handler = self.ext_renderer.instance_handler(user)
-            #~ a = users.MySettings.get_url_action('default_action')
-            a = users.MySettings.default_action
-            handler = self.action_call(None,a,dict(record_id=user.pk))
-            handler = "function(){%s}" % handler
-            mysettings = dict(text=_("My settings"),handler=js_code(handler))
-            login_menu_items = [mysettings]
-            if len(authorities):
-                #~ act_as = [
-                    #~ dict(text=unicode(u),handler=js_code("function(){Lino.set_subst_user(%s)}" % i)) 
-                        #~ for i,u in user.get_received_mandates()]
-                act_as = [
-                    dict(text=t,handler=js_code("function(){Lino.set_subst_user(%s,%s)}" % (v,py2js(t)))) 
-                        for v,t in authorities]
-                        #~ for v,t in user.get_received_mandates()]
-                act_as.insert(0,dict(
-                    text=_("Myself"),
-                    handler=js_code("function(){Lino.set_subst_user(null)}")))
-                act_as = dict(text=_("Act as..."),menu=dict(items=act_as))
-                
-                login_menu_items.insert(0,act_as)
-                #~ login_menu_items = [act_as,mysettings]
-                
-            if site.remote_user_header is None:
-                login_menu_items.append(dict(text=_("Log out"),handler=js_code('Lino.logout')))
-                login_menu_items.append(dict(text=_("Change password"),handler=js_code('Lino.change_password')))
-                login_menu_items.append(dict(text=_("Forgot password"),handler=js_code('Lino.forgot_password')))
-            
-            login_menu = dict(
-                text=user_text,
-                menu=dict(items=login_menu_items))
-            #~ else:
-                #~ login_menu = dict(text=user_text,handler=js_code(handler))
-                
-            #~ yield "Lino.login_menu = %s;" % py2js(login_menu)
-            #~ yield "Lino.main_menu = Lino.main_menu.concat(['->',Lino.login_menu]);"
-            yield "Lino.main_menu = Lino.main_menu.concat(['->',%s]);" % py2js(login_menu)
-                
-        elif site.user_model is not None: # 20121103
-            login_buttons = [
-              #~ dict(xtype="textfield",emptyText=_('Enter your username')),
-              #~ dict(xtype="textfield",emptyText=_('Enter your password'),inputType="password"),
-              dict(xtype="button",text=_("Log in"),handler=js_code('Lino.show_login_window')),
-              #~ dict(xtype="button",text="Register",handler=Lino.register),
-              ]
-            yield "Lino.main_menu = Lino.main_menu.concat(['->',%s]);" % py2js(login_buttons)
-                
+                login_buttons = [
+                  #~ dict(xtype="textfield",emptyText=_('Enter your username')),
+                  #~ dict(xtype="textfield",emptyText=_('Enter your password'),inputType="password"),
+                  dict(xtype="button",text=_("Log in"),handler=js_code('Lino.show_login_window')),
+                  #~ dict(xtype="button",text="Register",handler=Lino.register),
+                  ]
+                yield "Lino.main_menu = Lino.main_menu.concat(['->',%s]);" % py2js(login_buttons)
+                    
                 
         
         #~ yield "Lino.load_mask = new Ext.LoadMask(Ext.getBody(), {msg:'Immer mit der Ruhe...'});"
@@ -719,6 +724,7 @@ tinymce.init({
             
         if site.use_eid_jslib:
             p = site.build_media_url('eid-jslib')
+            p = request.build_absolute_uri(p)
             #~ print p
             yield '<applet code="org.jdesktop.applet.util.JNLPAppletLauncher"'
             yield 'codebase = "%s/"' % p
@@ -732,12 +738,14 @@ tinymce.init({
             yield '<param name="progressbar" value="true">'
             yield '<param name="jnlpNumExtensions" value="1">'
             yield '<param name="jnlpExtension1" value= "' + p + '/beid.jnlp">'
+            #~ yield '<param name="jnlpExtension1" value= "beid.jnlp">'
 
             yield '<param name="debug" value="false"/>'
             yield '<param name="Reader" value=""/>'
             yield '<param name="OCSP" value="-1"/>'
             yield '<param name="CRL" value="-1"/>'
-            yield '<param name="jnlp_href" value="' + p + '/beid_java_plugin.jnlp" />'
+            #~ yield '<param name="jnlp_href" value="' + p + '/beid_java_plugin.jnlp" />'
+            yield '<param name="jnlp_href" value="beid_java_plugin.jnlp" />'
             yield '</applet>'
 
 
@@ -860,9 +868,9 @@ tinymce.init({
         Make the dummy messages file.
         But only when generating for root user.
         """
-        if False: # no longer needed because babel extracts them
-            if jsgen._for_user_profile == dd.UserProfiles.admin:
-                make_dummy_messages_file(self.linolib_template_name(),messages)
+        #~ if False: # no longer needed because babel extracts them
+            #~ if jsgen._for_user_profile == dd.UserProfiles.admin:
+                #~ make_dummy_messages_file(self.linolib_template_name(),messages)
         
         #~ assert user == jsgen._for_user
         assert profile == jsgen._for_user_profile
@@ -904,7 +912,8 @@ tinymce.init({
                 #~ new_actors_list.append(a)
         #~ actors_list = new_actors_list
         
-        actors_list = [a for a in actors_list if a.default_action.get_view_permission(jsgen._for_user_profile)]
+        actors_list = [a for a in actors_list 
+            if a.default_action.get_view_permission(jsgen._for_user_profile)]
         
         #~ actors_list = [a for a in actors_list if a.get_view_permission(jsgen._for_user)]
           
@@ -922,20 +931,20 @@ tinymce.init({
         action_param_panels = set()
         def add(res,collector,fl,formpanel_name):
             # fl : a FormLayout
-            if fl is not None:
-                lh = fl.get_layout_handle(settings.SITE.ui)
-                if True: # 20121130 why was this?
-                    for e in lh.main.walk():
-                        e.loosen_requirements(res)
-                else:
-                    lh.main.loosen_requirements(res)
-                if fl in collector:
-                    pass
-                    #~ fl._using_actors.append(actor)
-                else:
-                    fl._formpanel_name = formpanel_name
-                    #~ fl._using_actors = [actor]
-                    collector.add(fl)
+            if fl is None: return
+            lh = fl.get_layout_handle(settings.SITE.ui)
+            if True: # 20121130 why was this?
+                for e in lh.main.walk():
+                    e.loosen_requirements(res)
+            else:
+                lh.main.loosen_requirements(res)
+            if fl in collector:
+                pass
+                #~ fl._using_actors.append(actor)
+            else:
+                fl._formpanel_name = formpanel_name
+                #~ fl._using_actors = [actor]
+                collector.add(fl)
                     
         #~ assert user == jsgen._for_user
         assert profile == jsgen._for_user_profile
@@ -1045,8 +1054,8 @@ tinymce.init({
     def lino_js_parts(self,profile):
         return ('cache','js','lino_' + profile.value + '_' + translation.get_language()+'.js')
         
-    def linolib_template_name(self):
-        return os.path.join(os.path.dirname(__file__),'linolib.js')
+    #~ def linolib_template_name(self):
+        #~ return os.path.join(os.path.dirname(__file__),'linolib.js')
         
     def linolib_template(self):
         env = jinja2.Environment(loader=jinja2.FileSystemLoader(
@@ -1230,14 +1239,15 @@ tinymce.init({
         yield "});"
         yield ""
       
-    #~ def js_render_FormPanelSubclass(self,dh,user):
     def js_render_FormPanelSubclass(self,dh):
         
         tbl = dh.layout._datasource
         if not dh.main.get_view_permission(jsgen._for_user_profile):
             msg = "No view permission for main panel of %s :" % dh.layout._formpanel_name
-            msg += " actor %s requires %s, but main requires %s)" % (tbl,tbl.required,dh.main.required)
-            raise Exception(msg)
+            msg += " main requires %s, but actor %s requires %s)" % (dh.main.required,tbl,tbl.required)
+            #~ raise Exception(msg)
+            logger.warning(msg)
+            return 
         
         yield ""
         yield "Lino.%s = Ext.extend(Lino.FormPanel,{" % dh.layout._formpanel_name
