@@ -13,7 +13,7 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
-Calls `initdb` with :attr:`lino.Site.demo_fixtures`.
+Calls `initdb` with :attr:`demo_fixtures <lino.ui.Site.demo_fixtures>`.
 """
 
 from django.conf import settings
