@@ -12,8 +12,9 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
-"""
 
+"""
+Deserves a docstring.
 """
 
 from __future__ import unicode_literals
@@ -30,7 +31,6 @@ from django.db import models
 from django.db.models import Q
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import pgettext_lazy as pgettext
-from django.utils import translation
 #~ from django.utils.translation import string_concat
 from django.contrib.contenttypes.models import ContentType
 from django.utils.encoding import force_unicode
@@ -40,8 +40,6 @@ from django.utils.importlib import import_module
 
 from north import dbutils
 from north.dbutils import dtosl
-from babel.dates import format_datetime, format_date
-from north import to_locale
 
 
 from lino import mixins
@@ -50,43 +48,28 @@ from lino import dd
 from lino.core import actions
 from lino.utils import AttrDict
 from lino.utils import ONE_DAY
-#~ from lino.ui import requests as ext_requests
 from lino.core import constants
 
-
 from lino.utils.xmlgen.html import E
 
-from lino.modlib.cal.utils import \
-    DurationUnits, Recurrencies, setkw, dt2kw, \
-    Weekdays, AccessClasses, CalendarAction
-    
-def format_time(t):
-    return t.strftime(settings.SITE.time_format_strftime)
-    
-def when_text(d,t):
-    if d is None: return ''
-    if t is None: return format_date(d,'yyyy MMM dd',locale=to_locale(translation.get_language()))
-    #~ if d.year == datetime.date.today().year:
-        #~ fmt = "%a" + settings.SITE.time_format_strftime
-    #~ else:
-        #~ fmt = "%a %y %b %d" + settings.SITE.time_format_strftime
-    #~ fmt = "%a %Y %b %d " + settings.SITE.time_format_strftime
-    #~ return datetime.datetime.combine(d,t).strftime(fmt)
-    fmt = "yyyy MMM dd (EE) HH:mm"
-    return format_datetime(datetime.datetime.combine(d,t),fmt,locale=to_locale(translation.get_language()))
-
+from lino.modlib.cal.utils import (
+    DurationUnits, Recurrencies, 
+    setkw, dt2kw, 
+    when_text, format_time,
+    Weekdays, AccessClasses, CalendarAction)
     
     
 contacts = dd.resolve_app('contacts')
 postings = dd.resolve_app('postings')
 outbox = dd.resolve_app('outbox')
 
-workflow = import_module('lino.modlib.cal.workflows.welfare')
+#~ workflow = import_module('lino.modlib.cal.workflows.welfare')
 #~ workflow = import_module('lino.modlib.cal.workflows.faggio')
+#~ for n in ('TaskStates','EventStates','GuestStates'):
+    #~ globals()[n] = getattr(workflow,n)
 
-for n in ('TaskStates','EventStates','GuestStates'):
-    globals()[n] = getattr(workflow,n)
-
+from lino.modlib.cal.workflows import (TaskStates,
+    EventStates,GuestStates)
 
 
 class CalendarType(object):
@@ -121,7 +104,6 @@ from django.core.validators import MinValueValidator
 
 
 
-#~ class Calendar(mixins.UserAuthored):
 class Calendar(mixins.PrintableType,outbox.MailableType,dd.BabelNamed):
     """
     A Calendar is a collection of events and tasks.
@@ -134,6 +116,7 @@ class Calendar(mixins.PrintableType,outbox.MailableType,dd.BabelNamed):
     templates_group = 'cal/Event'
     
     class Meta:
+        abstract = settings.SITE.is_abstract_model('cal.Calendar')
         verbose_name = _("Calendar")
         verbose_name_plural = _("Calendars")
         
@@ -149,9 +132,6 @@ class Calendar(mixins.PrintableType,outbox.MailableType,dd.BabelNamed):
     password = dd.PasswordField(_("Password"),
         max_length=200,blank=True) # ,null=True)
     readonly = models.BooleanField(_("read-only"),default=False)
-    #~ invite_team_members = models.BooleanField(
-        #~ _("Invite team members"),default=False)
-    invite_team_members = dd.ForeignKey('users.Team',blank=True,null=True)
     #~ is_default = models.BooleanField(
         #~ _("is default"),default=False)
     #~ is_private = models.BooleanField(
@@ -214,14 +194,14 @@ class Calendars(dd.Table):
     type name id 
     # description
     url_template username password
-    readonly invite_team_members color start_date
+    readonly color start_date
     build_method template email_template attach_to_email
     EventsByCalendar SubscriptionsByCalendar
     """
 
     insert_layout = dd.FormLayout("""
     name 
-    type invite_team_members color 
+    type color 
     """,window_size=(60,'auto'))
 
 #~ def default_calendar(user):
@@ -262,7 +242,7 @@ class Subscription(mixins.UserAuthored):
     #~ quick_search_fields = ('user__username','user__first_name','user__last_name')
     
 
-    calendar = models.ForeignKey(Calendar,help_text=_("""\
+    calendar = models.ForeignKey('cal.Calendar',help_text=_("""\
 The calendar you want to subscribe to.
 You can subscribe to *non-private* calendars of *other* users."""))
     is_hidden = models.BooleanField(
@@ -273,7 +253,7 @@ Whether this subscription should initially be hidden in your calendar panel.""")
 
 class Subscriptions(dd.Table):
     required = dd.required(user_groups='office',user_level='manager')
-    model = Subscription
+    model = 'cal.Subscription'
 
 class SubscriptionsByCalendar(Subscriptions):
     master_key = 'calendar'
@@ -287,67 +267,26 @@ class SubscriptionsByUser(Subscriptions):
     
 from lino.modlib.users.models import Membership    
 
-if False: # 20130320
-  
-  if settings.SITE.user_model:
-
-    class Membership(mixins.UserAuthored):
-        """
-        A Membership is when a User decides that subscribes to somebody else's Calendar.
-        
-        :user: points to the author (recipient) of this membership
-        :watched_user: points to the watched user
-        
-        """
-        
-        manager_level_field = 'office_level'
-        
-        class Meta:
-            verbose_name = _("Membership")
-            verbose_name_plural = _("Memberships")
-            
-        #~ quick_search_fields = ('user__username','user__first_name','user__last_name')
-        
-        watched_user = models.ForeignKey(settings.SITE.user_model,
-            help_text=_("""\
-    The user whose calendar events you want to see in team view."""))
-
-
-
-        @dd.chooser()
-        def watched_user_choices(cls,user):
-            return settings.SITE.user_model.objects.exclude(
-                #~ profile=dd.UserProfiles.blank_item).exclude(id=user.id) 20120829
-                profile=None).exclude(id=user.id)
-        
-            
-    class Memberships(dd.Table):
-        required = dd.required(user_groups='office',user_level='manager')
-        model = Membership
-
-
-    class MembershipsByUser(Memberships):
-        required = dd.required(user_groups='office')
-        master_key = 'user'
-        label = _("Team Members")
-
-
-
-class Room(dd.BabelNamed,contacts.ContactRelated):
+#~ ROOM_BASES = (dd.BabelNamed,contacts.ContactRelated):
+#~ class Room(ROOM_BASES):
+#~ class Room(dd.BabelNamed,contacts.ContactRelated):
+class Room(dd.BabelNamed):
     """
     A location where Events can happen.
     For a given Room you can see the :class:`EventsByRoom` 
     that happened (or will happen) there.
+    A Room is BabelNamed (has a multilingual name).
     """
     class Meta:
+        abstract = settings.SITE.is_abstract_model('cal.Room')
         verbose_name = _("Room")
         verbose_name_plural = _("Rooms")
         
-    def __unicode__(self):
-        s = dd.BabelNamed.__unicode__(self)
-        if self.company and self.company.city: 
-            s = '%s (%s)' % (self.company.city,s)
-        return s
+    #~ def __unicode__(self):
+        #~ s = dd.BabelNamed.__unicode__(self)
+        #~ if self.company and self.company.city: 
+            #~ s = '%s (%s)' % (self.company.city,s)
+        #~ return s
         
 
         
@@ -355,9 +294,9 @@ class Room(dd.BabelNamed,contacts.ContactRelated):
 class Rooms(dd.Table):
     help_text = _("List of rooms where calendar events can happen.")
     required = dd.required(user_groups='office',user_level='manager')
-    model = Room
+    model = 'cal.Room'
     detail_layout = """
-    id name company contact_person contact_role
+    id name 
     cal.EventsByRoom
     """
     
@@ -489,7 +428,7 @@ class EventGenerator(mixins.UserAuthored):
                 self.compare_auto_event(e,ae)
         # create new Events for remaining wanted
         for ae in wanted.values():
-            Event(**ae).save()
+            settings.SITE.modules.cal.Event(**ae).save()
         #~ logger.info("20130528 update_auto_events done")
             
     def compare_auto_event(self,obj,ae):
@@ -527,8 +466,8 @@ class EventGenerator(mixins.UserAuthored):
         #~ if until < wanted:
             #~ raise Warning("Series ends before it was started!")
         i = 0
-        max_occurences = rset.max_occurences or settings.SITE.max_auto_events
-        while i < max_occurences:
+        max_events = rset.max_events or settings.SITE.max_auto_events
+        while i < max_events:
             i += 1
             if until is not None and date > until:
                 return wanted
@@ -548,7 +487,7 @@ class EventGenerator(mixins.UserAuthored):
         
     def get_existing_auto_events(self):
         ot = ContentType.objects.get_for_model(self.__class__)
-        return Event.objects.filter(
+        return settings.SITE.modules.cal.Event.objects.filter(
             owner_type=ot,owner_id=self.pk,
             auto_type__isnull=False).order_by('auto_type')
         
@@ -657,12 +596,11 @@ class RecurrenceSet(Started,Ended):
         verbose_name = _("Recurrence Set")
         verbose_name_plural = _("Recurrence Sets")
     
-    every = models.IntegerField(_("Repeat every (value)"),
-        default=0)
     #~ every_unit = DurationUnits.field(_("Repeat every (unit)"),
-    every_unit = Recurrencies.field(_("Repeat every (unit)"),
+    every_unit = Recurrencies.field(_("Recurrency"),
         default=Recurrencies.monthly,
         blank=True) # iCal:DURATION
+    every = models.IntegerField(_("Repeat every"), default=0)
         
     monday    = models.BooleanField(Weekdays.monday.text)
     tuesday   = models.BooleanField(Weekdays.tuesday.text)
@@ -672,8 +610,8 @@ class RecurrenceSet(Started,Ended):
     saturday  = models.BooleanField(Weekdays.saturday.text)
     sunday    = models.BooleanField(Weekdays.sunday.text)
     
-    max_occurences = models.PositiveIntegerField(
-        _("Number of occurences"),
+    max_events = models.PositiveIntegerField(
+        _("Number of events"),
         blank=True,null=True)
         
         
@@ -702,7 +640,7 @@ class RecurrenceSet(Started,Ended):
         return _("Every %snd %s") % (self.every,weekdays)
         
         
-    calendar = models.ForeignKey(Calendar,null=True,blank=True,
+    calendar = models.ForeignKey('cal.Calendar',null=True,blank=True,
         help_text=_("""\
 The calendar to which events will be generated."""))
     #~ event_type = models.ForeignKey(EventType,null=True,blank=True)
@@ -777,7 +715,7 @@ class Component(ComponentBase,
     class Meta:
         abstract = True
         
-    calendar = models.ForeignKey(Calendar,verbose_name=_("Calendar"),blank=True,null=True)
+    calendar = models.ForeignKey('cal.Calendar',blank=True,null=True)
         
     access_class = AccessClasses.field(blank=True,help_text=_("""\
 Whether this is private, public or between.""")) # iCal:CLASS
@@ -941,6 +879,7 @@ class Event(Component,Ended,
     """
     
     class Meta:
+        abstract = settings.SITE.is_abstract_model('cal.Event')
         #~ abstract = True
         verbose_name = pgettext(u"cal",u"Event")
         verbose_name_plural = pgettext(u"cal",u"Events")
@@ -948,7 +887,7 @@ class Event(Component,Ended,
     transparent = models.BooleanField(_("Transparent"),default=False,help_text=_("""\
 Indicates that this Event shouldn't prevent other Events at the same time."""))
     #~ type = models.ForeignKey(EventType,null=True,blank=True)
-    room = models.ForeignKey(Room,null=True,blank=True) # iCal:LOCATION
+    room = dd.ForeignKey('cal.Room',null=True,blank=True) # iCal:LOCATION
     priority = models.ForeignKey(Priority,null=True,blank=True)
     #~ priority = Priority.field(_("Priority"),blank=True) # iCal:PRIORITY
     state = EventStates.field(default=EventStates.suggested) # iCal:STATUS
@@ -961,14 +900,11 @@ Indicates that this Event shouldn't prevent other Events at the same time."""))
     all_day = ExtAllDayField(_("all day"))
     #~ all_day = models.BooleanField(_("all day"),default=False)
     
-    if settings.SITE.user_model:
-        assigned_to = models.ForeignKey(settings.SITE.user_model,
-            verbose_name=_("Assigned to"),
-            related_name="cal_events_assigned",
-            blank=True,null=True
-            )
-    else:
-        assigned_to = dd.DummyField()
+    assigned_to = dd.ForeignKey(settings.SITE.user_model,
+        verbose_name=_("Assigned to"),
+        related_name="cal_events_assigned",
+        blank=True,null=True
+        )
         
         
     def is_editable_state(self):
@@ -977,11 +913,46 @@ Indicates that this Event shouldn't prevent other Events at the same time."""))
     def is_user_modified(self):
         return self.state != EventStates.suggested
         
-    def after_send_mail(self,mail,ar,kw):
-        if self.state == EventStates.assigned:
-            self.state = EventStates.notified
-            kw['message'] += '\n('  +_("Event %s has been marked *notified*.") % self + ')'
-            self.save()
+    #~ def after_send_mail(self,mail,ar,kw):
+        #~ if self.state == EventStates.assigned:
+            #~ self.state = EventStates.notified
+            #~ kw['message'] += '\n('  +_("Event %s has been marked *notified*.") % self + ')'
+            #~ self.save()
+            
+    def save(self,*args,**kw):
+        r = super(Event,self).save(*args,**kw)
+        self.add_guests()
+        return r
+            
+    def add_guests(self):
+        """
+        Decide whether it is time to add Guest instances for this event,
+        and if yes, call :meth:`suggest_guests` to instantiate them.
+        """
+        #~ print "20130722 Event.save"
+        #~ print "20130717 add_guests"
+        if settings.SITE.loading_from_dump: return
+        if not self.is_user_modified(): 
+            #~ print "not is_user_modified"
+            return
+        if not self.is_editable_state(): 
+            #~ print "not an editable state"
+            return 
+        if self.guest_set.all().count() > 0: 
+            #~ print "guest_set not empty"
+            return
+        for g in self.suggest_guests():
+            g.save()
+            #~ settings.SITE.modules.cal.Guest(event=self,partner=p).save()
+            
+    def suggest_guests(self):
+        """
+        Yield a list of Partner instances to be invited to this Event.
+        This method is called when :meth:`add_guests` decided so.
+        """
+        return []
+        
+        
             
     def before_ui_save(self,ar,**kw):
         """
@@ -996,8 +967,8 @@ Indicates that this Event shouldn't prevent other Events at the same time."""))
     def on_create(self,ar):
         self.start_date = datetime.date.today()
         self.start_time = datetime.datetime.now().time()
-        #~ if ar.subst_user is not None:
-        self.assigned_to = ar.subst_user
+        if self.assigned_to is None: # 20130722 e.g. CreateClientEvent sets it explicitly
+            self.assigned_to = ar.subst_user
         super(Event,self).on_create(ar)
         
     #~ def on_create(self,ar):
@@ -1099,16 +1070,17 @@ class EventInsert(EventDetail):
     #~ def setup_action_request(self,actor,ar):
         #~ # print "coucou"
         #~ # assert row is None
-        #~ dates_from = ar.param_values.dates_from or datetime.date.today()
-        #~ dates_to = ar.param_values.dates_to or dates_from
-        #~ ar.param_values.define('dates_from',dates_from + ONE_DAY)
-        #~ ar.param_values.define('dates_to',dates_to + ONE_DAY)
-        #~ # ar.param_values.dates_to += ONE_DAY
+        #~ start_date = ar.param_values.start_date or datetime.date.today()
+        #~ end_date = ar.param_values.end_date or start_date
+        #~ ar.param_values.define('start_date',start_date + ONE_DAY)
+        #~ ar.param_values.define('end_date',end_date + ONE_DAY)
+        #~ # ar.param_values.end_date += ONE_DAY
         #~ # logger.info("20121203 cal.NextDateAction.setup_action_request() %s",ar.param_values)
         #~ # return ar.success_response(refresh=True)
     
     
-unclear_event_states = (EventStates.suggested,EventStates.draft,EventStates.notified)
+#~ unclear_event_states = (EventStates.suggested,EventStates.draft,EventStates.notified)
+unclear_event_states = (EventStates.suggested,EventStates.draft)
 
 class Events(dd.Table):
     help_text = _("A List of calendar entries. Each entry is called an event.")
@@ -1135,35 +1107,28 @@ class Events(dd.Table):
     
     params_panel_hidden = True
     
-    parameters = dict(
-        #~ dates_from = dd.DatePickerField(_("Date from"),
-        dates_from = models.DateField(_("Date from"),
-            blank=True,null=True,help_text=u"""\
-Nur Termine ab diesem Datum."""),
-        #~ dates_to = dd.DatePickerField(_("until"),
-        dates_to = models.DateField(_("until"),
-            blank=True,null=True,help_text=u"""\
-Nur Termine bis zu diesem Datum."""),
-        user = models.ForeignKey(settings.SITE.user_model,
+    parameters = dd.ObservedPeriod(
+        user = dd.ForeignKey(settings.SITE.user_model,
             verbose_name=_("Responsible user"),
             blank=True,null=True,
-            help_text=u"""\
-Nur Termine dieses Benutzers."""),
+            help_text=_("Only events managed by this user.")),
+        project = dd.ForeignKey(settings.SITE.project_model,
+            blank=True,null=True),
         assigned_to = models.ForeignKey(settings.SITE.user_model,
             verbose_name=_("Assigned to"),
             blank=True,null=True,
-            help_text=u"""\
-Nur Termine, die diesem Benutzer zugewiesen sind."""),
-        state = EventStates.field(blank=True,help_text=u"""\
-Nur Termine in diesem Bearbeitungszustand."""),
+            help_text=_("Only events assigned to this user.")),
+        state = EventStates.field(blank=True,
+            help_text=_("Only events having this state.")),
         unclear = models.BooleanField(_("Unclear events"))
     )
     
     params_layout = """
-    dates_from dates_to user assigned_to state unclear
+    start_date end_date user assigned_to state 
+    unclear project
     """
     #~ params_layout = dd.Panel("""
-    #~ dates_from dates_to other
+    #~ start_date end_date other
     #~ """,other="""
     #~ user 
     #~ assigned_to 
@@ -1180,6 +1145,8 @@ Nur Termine in diesem Bearbeitungszustand."""),
             
         if ar.param_values.user:
             qs = qs.filter(user=ar.param_values.user)
+        if settings.SITE.project_model is not None and ar.param_values.project:
+            qs = qs.filter(project=ar.param_values.project)
         if ar.param_values.assigned_to:
             qs = qs.filter(assigned_to=ar.param_values.assigned_to)
 
@@ -1189,23 +1156,23 @@ Nur Termine in diesem Bearbeitungszustand."""),
         if ar.param_values.unclear:
             qs = qs.filter(state__in=unclear_event_states)
             
-        if ar.param_values.dates_from:
-            if ar.param_values.dates_to:
-                qs = qs.filter(start_date__gte=ar.param_values.dates_from)
+        if ar.param_values.start_date:
+            if ar.param_values.end_date:
+                qs = qs.filter(start_date__gte=ar.param_values.start_date)
             else:
-                qs = qs.filter(start_date=ar.param_values.dates_from)
-        if ar.param_values.dates_to:
-            qs = qs.filter(start_date__lte=ar.param_values.dates_to)
+                qs = qs.filter(start_date=ar.param_values.start_date)
+        if ar.param_values.end_date:
+            qs = qs.filter(start_date__lte=ar.param_values.end_date)
         return qs
         
     @classmethod
     def get_title_tags(self,ar):
         for t in super(Events,self).get_title_tags(ar):
             yield t
-        if ar.param_values.dates_from or ar.param_values.dates_to:
+        if ar.param_values.start_date or ar.param_values.end_date:
             yield unicode(_("Dates %(min)s to %(max)s") % dict(
-              min=ar.param_values.dates_from or'...',
-              max=ar.param_values.dates_to or '...'))
+              min=ar.param_values.start_date or'...',
+              max=ar.param_values.end_date or '...'))
               
         if ar.param_values.state:
             yield unicode(ar.param_values.state)
@@ -1213,6 +1180,9 @@ Nur Termine in diesem Bearbeitungszustand."""),
         if ar.param_values.user:
             yield unicode(ar.param_values.user)
             
+        if settings.SITE.project_model is not None and ar.param_values.project:
+            yield unicode(ar.param_values.project)
+            
         if ar.param_values.assigned_to:
             yield unicode(self.parameters['assigned_to'].verbose_name) + ' ' + unicode(ar.param_values.assigned_to)
 
@@ -1243,6 +1213,9 @@ if settings.SITE.project_model:
     class EventsByProject(Events):
         required = dd.required(user_groups='office')
         master_key = 'project'
+        auto_fit_column_widths = True
+        column_names = 'when_text user summary workflow_buttons'
+
     
 if settings.SITE.user_model:    
   
@@ -1273,8 +1246,8 @@ if settings.SITE.user_model:
         def param_defaults(self,ar,**kw):
             kw = super(MyUnclearEvents,self).param_defaults(ar,**kw)
             kw.update(unclear=True)
-            kw.update(dates_from=datetime.date.today())
-            kw.update(dates_to=datetime.date.today()+ONE_DAY)
+            kw.update(start_date=datetime.date.today())
+            kw.update(end_date=datetime.date.today()+ONE_DAY)
             return kw
         
     class EventsAssignedToMe(Events):
@@ -1661,18 +1634,88 @@ class Guests(dd.Table):
     model = Guest
     required = dd.required(user_groups='office',user_level='admin')
     column_names = 'partner role workflow_buttons remark event *'
-    #~ workflow_state_field = 'state'
-    #~ column_names = 'contact role state remark event *'
-    #~ workflow_actions = ['invite','notify']
-    #~ workflow_owner_field = 'event__user'
+    detail_layout = """
+    event partner role
+    state remark workflow_buttons
+    outbox.MailsByController
+    """
+    insert_layout = dd.FormLayout("""
+    event 
+    partner 
+    role
+    """,window_size=(60,'auto'))
+    
+    parameters = dd.ObservedPeriod(
+        user = dd.ForeignKey(settings.SITE.user_model,
+            verbose_name=_("Responsible user"),
+            blank=True,null=True,
+            help_text=_("Only events managed by this user.")),
+        project = dd.ForeignKey(settings.SITE.project_model,
+            blank=True,null=True),
+        event_state = EventStates.field(blank=True,
+            verbose_name=_("Event state"),
+            help_text=_("Only events having this state.")),
+        guest_state = GuestStates.field(blank=True,
+            verbose_name=_("Guest state"),
+            help_text=_("Only guests having this state.")),
+    )
+    
+    params_layout = "start_date end_date user event_state guest_state project"
+    
+    @classmethod
+    def get_request_queryset(self,ar):
+        #~ logger.info("20121010 Clients.get_request_queryset %s",ar.param_values)
+        qs = super(Guests,self).get_request_queryset(ar)
+            
+        if ar.param_values.user:
+            qs = qs.filter(event__user=ar.param_values.user)
+        if settings.SITE.project_model is not None and ar.param_values.project:
+            qs = qs.filter(event__project=ar.param_values.project)
+
+        if ar.param_values.event_state:
+            qs = qs.filter(event__state=ar.param_values.event_state)
+            
+        if ar.param_values.guest_state:
+            qs = qs.filter(state=ar.param_values.guest_state)
+            
+        if ar.param_values.start_date:
+            if ar.param_values.end_date:
+                qs = qs.filter(event__start_date__gte=ar.param_values.start_date)
+            else:
+                qs = qs.filter(event__start_date=ar.param_values.start_date)
+        if ar.param_values.end_date:
+            qs = qs.filter(event__end_date__lte=ar.param_values.end_date)
+        return qs
+        
+    @classmethod
+    def get_title_tags(self,ar):
+        for t in super(Guests,self).get_title_tags(ar):
+            yield t
+        if ar.param_values.start_date or ar.param_values.end_date:
+            yield unicode(_("Dates %(min)s to %(max)s") % dict(
+              min=ar.param_values.start_date or'...',
+              max=ar.param_values.end_date or '...'))
+              
+        if ar.param_values.event_state:
+            yield unicode(ar.param_values.event_state)
+            
+        if ar.param_values.guest_state:
+            yield unicode(ar.param_values.guest_state)
+            
+        if ar.param_values.user:
+            yield unicode(ar.param_values.user)
+            
+        if settings.SITE.project_model is not None and ar.param_values.project:
+            yield unicode(ar.param_values.project)
+            
+    
     
-    #~ def setup_actions(self):
-        #~ super(dd.Table,self).setup_actions()
-        #~ self.add_action(mails.CreateMailAction())
         
 class GuestsByEvent(Guests):
     master_key = 'event'
     required = dd.required(user_groups='office')
+    auto_fit_column_widths = True
+    column_names = 'partner role workflow_buttons'
 
 class GuestsByRole(Guests):
     master_key = 'role'
@@ -1681,9 +1724,11 @@ class GuestsByRole(Guests):
 if settings.SITE.is_installed('contacts'):
   
   class GuestsByPartner(Guests):
+      label = _("Presences")
       master_key = 'partner'
       required = dd.required(user_groups='office')
-      column_names = 'event role workflow_buttons remark *'
+      column_names = 'event__when_text workflow_buttons'
+      auto_fit_column_widths = True
 
   class MyPresences(GuestsByPartner):
       required = dd.required(user_groups='office')
@@ -2204,15 +2249,15 @@ class UpdateReminders(actions.RowAction):
         return ar.ui.success(msg,**kw)
         
 
-from lino.ui import models as ui
+system = dd.resolve_app('system')
 
-class Home(ui.Home):
+class Home(system.Home):
     """
     Deserves better documentation.
     """
     #~ debug_permissions = True 
 
-    label = ui.Home.label
+    label = system.Home.label
     app_label = 'lino'
     detail_layout = """
     quick_links:80x1
@@ -2265,7 +2310,7 @@ def customize_users():
     ))
     dd.inject_field(settings.SITE.user_model,
         'calendar',
-        models.ForeignKey(Calendar,
+        models.ForeignKey('cal.Calendar',
             blank=True,null=True,
             verbose_name=_("Default calendar"),
             help_text=_("""The default calendar for your events and tasks.""")
@@ -2351,7 +2396,7 @@ def setup_main_menu(site,ui,profile,m):
     
 def setup_config_menu(site,ui,profile,m): 
     m  = m.add_menu("cal",MODULE_LABEL)
-    m.add_action(Rooms)
+    m.add_action('cal.Rooms')
     m.add_action(Priorities)
     #~ m.add_action(AccessClasses)
     #~ m.add_action(EventStatuses)
@@ -2399,4 +2444,3 @@ def get_todo_tables(ar):
 customize_users()
 
 
-
