@@ -1,5 +1,5 @@
 SETUP_INFO = dict(name = 'lino',
-  version = '1.6.10',
+  version = '1.6.11',
   install_requires = ['North==0.1.5','djangosite>=0.1.5','PyYAML','odfpy','jinja2','appy'],
   description = "A framework for writing desktop-like web applications using Django and ExtJS",
   license = 'GPL',
@@ -32,26 +32,22 @@ SETUP_INFO.update(long_description = """\
 Lino is a high-level framework for writing desktop-like customized 
 database applications based on `Django <https://www.djangoproject.com/>`_
 and `Sencha ExtJS <http://www.sencha.com/products/extjs/>`_.
+
+Examples of Lino applications are
+`Lino-Welfare <http://welfare.lino-framework.org>`__,
+`Lino-Patrols <http://patrols.lino-framework.org>`__
+or
+`Lino-Faggio <http://faggio.lino-framework.org>`__.
+
 A Lino application is technically just a Django project, 
 but the application developer does not need to write any 
 URLconf, HTML nor CSS (`more <http://lino-framework.org/about>`_)
 
-The following real-world applications use the Lino framework:
-
-- `Lino-Welfare <http://welfare.lino-framework.org>`__
-
-Lino uses the following projects by the same author:
-
-- `atelier <http://atelier.lino-framework.org>`__
-  provides some general Python tools.
-  
-- `djangosite <http://site.lino-framework.org>`__
-  provides startup signals and the `settings.SITE` object.
-  
-- `north <http://north.lino-framework.org>`__
-  provides python dumps, multilingual database content 
-  and data migration.
-
+Lino is based on three other projects by the same author:
+`atelier <http://atelier.lino-framework.org>`__,
+`djangosite <http://site.lino-framework.org>`__
+and
+`north <http://north.lino-framework.org>`__.
   
 """)
 
@@ -61,6 +57,8 @@ lino.core
 lino.extjs
 lino.history
 lino.modlib
+lino.modlib.auto
+lino.modlib.auto.sales
 lino.modlib.contacts
 lino.modlib.contacts.fixtures
 lino.modlib.countries
@@ -89,6 +87,7 @@ lino.modlib.cal.management.commands
 lino.modlib.cal.fixtures
 lino.modlib.cal.tests
 lino.modlib.cal.workflows
+lino.modlib.reception
 lino.modlib.tickets
 lino.modlib.tickets.fixtures
 lino.modlib.vocbook
@@ -101,8 +100,8 @@ lino.modlib.accounts
 lino.modlib.vat
 lino.modlib.households
 lino.modlib.households.fixtures
-lino.modlib.school
-lino.modlib.school.fixtures
+lino.modlib.courses
+lino.modlib.courses.fixtures
 lino.modlib.about
 lino.modlib.pages
 lino.modlib.pages.fixtures
@@ -116,6 +115,9 @@ lino.modlib.declarations
 lino.modlib.events
 lino.modlib.events.fixtures
 lino.modlib.events.tests
+lino.modlib.system
+lino.modlib.system.fixtures
+lino.modlib.system.tests
 lino.test_apps
 lino.test_apps.20090714
 lino.test_apps.20090717
@@ -135,6 +137,7 @@ lino.utils.xmlgen
 lino.utils.xmlgen.intervat
 lino.utils.xmlgen.cbss
 lino.utils.xmlgen.odf
+lino.utils.xmlgen.sepa
 lino.tutorials
 lino.tutorials.mini
 lino.tutorials.lets1
@@ -144,8 +147,6 @@ lino.management
 lino.management.commands
 lino.mixins
 lino.ui
-lino.ui.fixtures
-lino.ui.tests
 lino.projects
 lino.projects.belref
 lino.projects.belref.fixtures
@@ -159,14 +160,13 @@ lino.projects.crl
 lino.projects.crl.fixtures
 lino.projects.events
 lino.projects.homeworkschool
+lino.projects.homeworkschool.settings
 lino.projects.homeworkschool.fixtures
+lino.projects.i18n
 lino.projects.igen
 lino.projects.igen.tests
 lino.projects.min1
 lino.projects.min2
-lino.projects.unused_polls_tutorial
-lino.projects.unused_polls_tutorial.polls
-lino.projects.unused_polls_tutorial.polls.fixtures
 lino.projects.presto
 lino.projects.presto.fixtures
 lino.projects.std
