@@ -33,6 +33,8 @@ from urllib import urlencode
 
 from pkg_resources import Requirement, resource_filename, DistributionNotFound
 
+
+
 def buildurl(*args,**kw):
     url = '/' + ("/".join(args))
     if len(kw):
@@ -45,8 +47,7 @@ from lino.utils import AttrDict
 
 
 import lino
-
-
+from lino import ad
 
 
 class Site(lino.Site):
@@ -142,7 +143,14 @@ class Site(lino.Site):
     Set it to `None` to remove any user management 
     (feature used by e.g. :mod:`lino.test_apps.1`)
     """
-    
+
+    auth_middleware = None
+    """
+    Override used Authorisation middlewares with supplied tuple of 
+    middleware class names.
+
+    If None, use logic described in :doc:`/topics/auth`
+    """
     
     legacy_data_path = None
     """
@@ -210,6 +218,37 @@ class Site(lino.Site):
       
     """
     
+    is_demo_site = True
+    """
+    When this is `True`, then this site runs in "demo" mode.     
+    "Demo mode" means:
+    
+    - the welcome text for anonymous users says "This demo site has X 
+      users, they all have "1234" as password", 
+      followed by a list of available usernames.
+    
+    Default value is `True`.
+    On a production site you will of course set this to `False`.
+    
+    See also :attr:`demo_fixtures`.
+    
+    """
+    
+    demo_email = 'demo@example.com'
+    """
+    
+    """
+    
+    demo_fixtures = ['std','demo','demo2']
+    """
+    The list of fixtures to be loaded by the 
+    :mod:`initdb_demo <lino.management.commands.initdb_demo>`
+    command.
+    
+    """
+    
+    
+   
     
     use_spinner = False # doesn't work. leave this to False
     
@@ -247,10 +286,14 @@ class Site(lino.Site):
     
     
     See also  
-    http://groups.google.com/group/django-users/browse_thread/thread/c95ba83e8f666ae5?pli=1
-    http://groups.google.com/group/django-users/browse_thread/thread/27f035aa8e566af6
-    https://code.djangoproject.com/ticket/8906
-    https://code.djangoproject.com/wiki/BackwardsIncompatibleChanges#ChangedthewayURLpathsaredetermined
+    
+    - `telling Django to recognize a different application root url
+      <http://groups.google.com/group/django-users/browse_thread/thread/c95ba83e8f666ae5?pli=1>`__
+    - `How to get site's root path in Django 
+      <http://groups.google.com/group/django-users/browse_thread/thread/27f035aa8e566af6>`__
+    - `#8906 django.contrib.auth settings.py URL's aren't portable <https://code.djangoproject.com/ticket/8906>`__
+    - `Changed the way URL paths are determined 
+      <https://code.djangoproject.com/wiki/BackwardsIncompatibleChanges#ChangedthewayURLpathsaredetermined>`__
     """
     
     use_extjs = True
@@ -458,7 +501,8 @@ class Site(lino.Site):
     """
     Whether to make use of `Ext.QuickTips
     <http://docs.sencha.com/ext-js/3-4/#!/api/Ext.QuickTips>`_
-    when displaying help texts defined in :class:`lino.models.HelpText`
+    when displaying :ref:`help_texts`.
+    
     """
     
     use_css_tooltips = False
@@ -499,7 +543,8 @@ class Site(lino.Site):
     
     use_davlink = False
     """
-    Set this to `False` if you don't need WebDAV-enabled links.
+    Set this to `True` if this site should feature WebDAV-enabled links 
+    using :ref:`davlink`.
     """
     
     max_auto_events = 72
@@ -514,32 +559,7 @@ class Site(lino.Site):
     #~ (see :mod:`lino.mixins.mergeable`).
     #~ """
     
-    override_modlib_models = []
-    """
-    A list of names of modlib models which are being 
-    redefined by this application.
-    
-    The following modlib models currently support this:
-    - :class:`contacts.Person <lino.modlib.contacts.models.Person>`
-    - :class:`contacts.Company <lino.modlib.contacts.models.Company>`
-    
-    Usage: in your application's `settings.py`, specify::
-    
-      class Site(Site):
-          override_modlib_models = ['contacts.Person']
-          
-    This will cause the modlib Person model to be abstract, 
-    and hence your application is responsible for defining another 
-    `Person` class with "contacts" as `app_label`::
-          
-      class Person(contacts.Person,mixins.Born):
-          class Meta(contacts.Person.Meta):
-              app_label = 'contacts'
-              
-          def kiss(self):
-              ...
-    
-    """
+    override_modlib_models = None
     
     sidebar_width = 0
     """
@@ -568,6 +588,21 @@ class Site(lino.Site):
         installed_apps = tuple([str(x) for x in installed_apps])
         self.update_settings(INSTALLED_APPS=installed_apps)
         
+        if self.override_modlib_models is None:
+            self.override_modlib_models = set()
+            from django.utils.importlib import import_module
+            for n in installed_apps:
+                m = import_module(n)
+                app = getattr(m,'App',None)
+                if app is not None:
+                    if app.extends_models is not None:
+                        for m in app.extends_models:
+                            self.override_modlib_models.add(m)
+                            
+        
+        #~ fd = list()
+        #~ self.update_settings(FIXTURE_DIRS=tuple(settings_subdirs('fixtures')))
+        
         if self.webdav_url is None:
             self.webdav_url = '/media/webdav/'
         if self.webdav_root is None:
@@ -627,6 +662,25 @@ class Site(lino.Site):
             #~ sys.exit(-10)
         #~ raise Exception("20130302")
         
+        
+    def do_site_startup(self):
+        """
+        """
+        super(Site,self).do_site_startup()
+        
+        from django.conf import settings
+        
+        if self.build_js_cache_on_startup is None:
+            from lino.core.dbutils import is_devserver
+            self.build_js_cache_on_startup = not (settings.DEBUG or is_devserver())
+        
+        from lino.core.web import web_setup
+        web_setup(self)
+        
+        from lino.ui.ui import ExtUI
+        self.ui = ExtUI(self)
+    
+
 
     def is_abstract_model(self,name):
         """
@@ -679,7 +733,7 @@ class Site(lino.Site):
       
     #~ @property
     #~ def site_config(self):
-        #~ SiteConfig = self.modules.ui.SiteConfig
+        #~ SiteConfig = self.modules.system.SiteConfig
         #~ try:
             #~ return SiteConfig.objects.get(pk=1)
         #~ except SiteConfig.DoesNotExist:
@@ -705,8 +759,8 @@ class Site(lino.Site):
             #~ from lino.core.dbutils import resolve_model
             #~ from lino.core.dbutils import obj2str
             #~ from lino.utils import dblogger as logger
-            #~ SiteConfig = resolve_model('ui.SiteConfig')
-            SiteConfig = self.modules.ui.SiteConfig
+            #~ SiteConfig = resolve_model('system.SiteConfig')
+            SiteConfig = self.modules.system.SiteConfig
             #~ from .models import SiteConfig
             #~ from django.db.utils import DatabaseError
             try:
@@ -728,6 +782,10 @@ class Site(lino.Site):
         return self._site_config
     #~ site_config = property(get_site_config)
     
+    #~ def shutdown(self):
+        #~ self.clear_site_config()
+        #~ return super(Site,self).shutdown()
+        
     def clear_site_config(self):
         """
         Clear the cached SiteConfig instance. 
@@ -859,16 +917,21 @@ class Site(lino.Site):
         #~ if self.user_model is None:
             #~ yield 'lino.utils.auth.NoUserMiddleware'
         #~ elif self.remote_user_header:
-        if self.user_model is None:
-            yield 'lino.utils.auth.NoUserMiddleware'
+
+        if self.auth_middleware:
+            yield self.auth_middleware
         else:
-            if self.remote_user_header:
-                yield 'lino.utils.auth.RemoteUserMiddleware'
-                #~ yield 'django.middleware.doc.XViewMiddleware'
+            if self.user_model is None:
+                yield 'lino.utils.auth.NoUserMiddleware'
             else:
-                # 20121003 : not using remote http auth, so we need sessions
-                yield 'django.contrib.sessions.middleware.SessionMiddleware'
-                yield 'lino.utils.auth.SessionUserMiddleware'
+                if self.remote_user_header:
+                    yield 'lino.utils.auth.RemoteUserMiddleware'
+                    #~ yield 'django.middleware.doc.XViewMiddleware'
+                else:
+                    # 20121003 : not using remote http auth, so we need sessions
+                    yield 'django.contrib.sessions.middleware.SessionMiddleware'
+                    yield 'lino.utils.auth.SessionUserMiddleware'
+
                 #~ raise Exception("""\
     #~ `user_model` is not None, but no `remote_user_header` in your settings.SITE.""")
         #~ yield 'lino.utils.editing.EditingMiddleware'
@@ -900,8 +963,7 @@ class Site(lino.Site):
         """
         Return a chunk of html to be displayed in the main area of the admin index.
         This is being called only if :meth:`get_main_action` returns `None`.
-        The default implementation returns the message 
-        "You are now in the admin section..."
+        The default implementation renders the `admin_main.html` template.
         """
         from lino.core import web
         return web.render_from_request(request,'admin_main.html')
@@ -922,10 +984,10 @@ class Site(lino.Site):
 
     def get_installed_apps(self):
         """
-        This method is expected to return or yield the list of strings 
+        This method is expected to yield the list of strings 
         to be stored into Django's :setting:`INSTALLED_APPS` setting.
         """
-        yield 'lino.ui'
+        #~ yield 'lino.ui'
         if self.user_model is not None and self.remote_user_header is None:
             yield 'django.contrib.sessions' # 20121103
         if self.django_admin_prefix:
@@ -1072,11 +1134,6 @@ class Site(lino.Site):
         return requests.BaseRequest(
             renderer=self.ui.text_renderer,
             user=u)
-        
-
-
-
-
 
 
 
@@ -1199,7 +1256,6 @@ class Site(lino.Site):
         )
         return urlpatterns
       
-            
 
     def get_ext_urls(self):
         
@@ -1247,8 +1303,10 @@ class Site(lino.Site):
         
     def get_patterns(self):
         self.startup()
-        from lino.core.signals import database_ready
+        
+        from djangosite.signals import database_ready
         database_ready.send(self)
+        
         #~ self.logger.info("20130418 get_patterns()")
         from django.conf.urls import patterns, url, include
 
@@ -1301,6 +1359,24 @@ class Site(lino.Site):
         return s
 
 
+    def for_each_app(self,func,*args,**kw):
+        """
+        Successor of :meth:`djangosite.Site.on_each_app`. 
+        This also loops over 
+        
+        - apps that don't have a models module
+        - inherited apps
+        
+        """
+        from django.utils.importlib import import_module
+
+        for app_name in self.get_installed_apps():
+            app_mod = import_module(app_name)
+            app = getattr(app_mod,'App',None)
+            if app is not None and issubclass(app,ad.App) and app.extends:
+                parent = import_module(app.extends)
+                func(app.extends,parent,*args,**kw)
+            func(app_name,app_mod,*args,**kw)
 
 
 
