@@ -25,6 +25,7 @@ from django.utils.translation import ugettext as _
 from django.utils.translation import string_concat
 from django.utils.encoding import force_unicode
 from django.conf import settings
+from django.contrib.contenttypes import generic
 
 import lino
 
@@ -76,6 +77,9 @@ def form_field_name(f):
     else:
         return f.name
         
+def has_fk_renderer(fld):
+    #~ return isinstance(fld,(models.ForeignKey,generic.GenericForeignKey))
+    return isinstance(fld,models.ForeignKey)
 
 def rpt2url(rpt):
     return '/' + rpt.app_label + '/' + rpt.__name__
@@ -164,7 +168,6 @@ class GridColumn(jsgen.Component):
     
     def __init__(self,layout_handle,index,editor,**kw):
         """
-        editor may be a Panel for columns on a GenericForeignKey
         """
         #~ print 20100515, editor.name, editor.__class__
         #~ assert isinstance(editor,FieldElement), \
@@ -223,7 +226,7 @@ class GridColumn(jsgen.Component):
                 """
                 FK fields are clickable only if their target has a detail view
                 """
-                rpt = fld.rel.to._lino_default_table
+                rpt = fld.rel.to.get_default_table()
                 if rpt.detail_action is not None:
                     if rpt.detail_action.get_view_permission(jsgen._for_user_profile):
                         return "Lino.fk_renderer('%s','Lino.%s')" % (
@@ -242,11 +245,12 @@ class GridColumn(jsgen.Component):
             #~ elif isinstance(editor.field,dd.LinkedForeignKey):
                 #~ rend = "Lino.lfk_renderer(this,'%s')" % \
                   #~ (editor.field.name + ext_requests.CHOICES_HIDDEN_SUFFIX)
-            elif isinstance(editor.field,models.ForeignKey):
+            #~ elif isinstance(editor.field,models.ForeignKey):
+            elif has_fk_renderer(editor.field):
                 rend = fk_renderer(editor.field,editor.field.name)
             elif isinstance(editor.field,fields.VirtualField):
                 kw.update(sortable=False)
-                if isinstance(editor.field.return_type,models.ForeignKey):
+                if has_fk_renderer(editor.field.return_type):
                     rend = fk_renderer(editor.field.return_type,editor.field.name)
                 #~ elif isinstance(editor.field.return_type,models.DecimalField):
                     #~ print "20120510 Lino.hide_zero_renderer", editor.field.name
@@ -446,22 +450,55 @@ class LayoutElement(VisibleComponent):
         
     def loosen_requirements(self,actor):
         """
-        Retain only those requirements of obj which are also in actor.
+        Retain only those requirements of `self` which are 
+        also in `actor`.
+        
+        For example an InsertFormPanel has initially the requirements 
+        of the actor who defines it. The actor may not be visible to the current user. 
+        But the panel may be used by other actors which are visible 
+        because they have with less requirements.
         """
+        #~ if str(self.layout_handle.layout._datasource) == 'cal.Guests':
+            #~ logger.info("20130720 %s loosens requirements from %s",self.layout_handle.layout,actor)
         if self.layout_handle.layout._datasource == actor:
-            return 
+            return # nothing to loosen
+            
+        
         #~ kw = actor.required
         new = dict()
-        loosened = set()
+        loosened = False
         for k,v in self.required.items():
-            if actor.required.has_key(k):
+            if k == 'user_groups': # 
+                """
+                loosening user_groups requirements means to *add* them
+                """
+                if actor.required.has_key(k):
+                    user_groups = actor.required[k]
+                    if isinstance(user_groups,basestring):
+                        user_groups = user_groups.split()
+                    if isinstance(self.required[k],basestring):
+                        self.required[k] = self.required[k].split()
+                    for group in user_groups:
+                        if not group in self.required[k]:
+                            self.required[k].append(group)
+                            loosened = True
+                    #~ self.required[k] = ' '.join(set(actor.required[k].split() + self.required[k].split()))
+                else:
+                    del self.required[k]
+                    loosened = True
+            elif actor.required.has_key(k):
                 if actor.required[k] < v:
-                    loosened.add(k)
+                    loosened = True
                     self.required[k] = actor.required[k]
             else:
-                loosened.add(k)
+                loosened = True
                 del self.required[k]
             
+        #~ if self.layout_handle.layout._datasource == actor:
+            #~ if loosened:
+                #~ raise Exception("20130720 Expected nothing to loosen")
+            #~ return # nothing to loosen
+            
         #~ for k,v in actor.required.items():
             #~ new[k] = v
             #~ if k in self.required:
@@ -469,10 +506,13 @@ class LayoutElement(VisibleComponent):
                     #~ removed.add(k)
             #~ else:
                 #~ removed.add(k)
+        #~ if str(actor) == 'cal.Guests':
+            #~ logger.info("20130720 loosen_requirements %r of %s from %s",','.join(loosened),self.layout_handle.layout,actor)
         if loosened:
             #~ self.required = new
             self.install_permission_handler()
-            #~ logger.info("20121116 loosened requirements %s using %s by %s",,self.layout_handle.layout,actor)
+            #~ if str(actor) == 'cal.Guests':
+                #~ logger.info("20121116 loosened requirements %s of %s from %s",loosened,self.layout_handle.layout,actor)
             #~ logger.info("20121116 %s uses %s loosening requirements %s",actor,self.layout_handle.layout,','.join(loosened))
             #~ if self.layout_handle.layout._datasource != actor:
                 #~ raise Exception("%s != %s" % (self.layout_handle.layout._datasource,actor))
@@ -860,6 +900,15 @@ class CharFieldElement(FieldElement):
         if self.field.max_length is not None:
             if self.field.max_length <= 10:
                 kw.update(boxMinWidth=js_code('Lino.chars2width(%d)' % self.field.max_length))
+                
+        for lino_name,extjs_name in (
+          ('regex','regex'),
+          ('mask_re','maskRe'),
+          ('strip_chars_re','stripCharsRe'),
+          ):
+            v = getattr(self.field,lino_name,None)
+            if v is not None:
+                kw[extjs_name] = js_code(v)
         
         #~ kw.update(style=dict(padding=DEFAULT_PADDING))
         #~ kw.update(margins='10px')
@@ -915,10 +964,19 @@ class ChoicesFieldElement(ComboFieldElement):
         return kw
         
 class ChoiceListFieldElement(ChoicesFieldElement):
+    """
+    Like :class:`ChoicesFieldElement`, but we use the fact that 
+    choicelists are actors to define them once and refer to them.
+    Special case are choicelist fields with blank=True: these 
+    must dynamicaly add a blank choice to the the choicelist.
+    """
     def get_field_options(self,**kw):
         kw = ComboFieldElement.get_field_options(self,**kw)
         #~ kw.update(store=js_code('Lino.%s.choices' % self.field.choicelist.actor_id))
-        kw.update(store=js_code('Lino.%s' % self.field.choicelist.actor_id))
+        js = 'Lino.%s' % self.field.choicelist.actor_id
+        if self.field.blank:
+            js = "[['','<br>']].concat(%s)" % js
+        kw.update(store=js_code(js))
         return kw
 
 class RemoteComboFieldElement(ComboFieldElement):
@@ -1352,6 +1410,7 @@ class BooleanFieldElement(BooleanMixin,FieldElement):
                 return 
                 #~ dv = dv()
             kw.update(checked=dv)
+            #~ kw.update(value=dv)
             #~ self.remove('value')
 
     def get_field_options(self,**kw):
@@ -1368,7 +1427,7 @@ class BooleanFieldElement(BooleanMixin,FieldElement):
                 #~ js = "Lino.show_mti_child('%s','%s')" % (self.field.name,url)
                 #~ label += """ (<a href="javascript:%s">%s</a>)""" % (js,_("show"))
             if isinstance(self.field,mti.EnableChild):
-                rpt = self.field.child_model._lino_default_table
+                rpt = self.field.child_model.get_default_table()
                 if rpt.detail_action is not None:
                     js = "Lino.show_mti_child('%s',Lino.%s)" % (
                       self.field.name,
@@ -2098,7 +2157,10 @@ class GridElement(Container):
             else:
                 nv = col.value2num(v)
                 if nv != 0:
-                    sums[i] += nv
+                    try:
+                        sums[i] += nv
+                    except TypeError as e:
+                        raise Exception("Cannot compute %r + %r" % (sums[i],nv))
                     has_numeric_value = True
                 td = col.value2html(ar,v,**cellattrs)
             col.apply_cell_format(td)
@@ -2251,6 +2313,7 @@ _FIELD2ELEM = (
     #~ (models.ManyToManyField, M2mGridElement),
     (models.ForeignKey, ForeignKeyElement),
     (models.AutoField, AutoFieldElement),
+    #~ (generic.GenericForeignKey, GenericForeignKeyElement),
 )
     
 TRIGGER_BUTTON_WIDTH = 3
