@@ -16,6 +16,8 @@ Defines the `Store` class and its fields
 
 """
 
+from __future__ import unicode_literals
+
 import logging
 logger = logging.getLogger(__name__)
 
@@ -40,9 +42,7 @@ from lino.utils.quantities import parse_decimal
 #~ from lino.utils.xmlgen import etree
 #~ from lino.utils.xmlgen.html import E
 
-#~ from . import ext_requests
-#~ from lino.ui import requests as ext_requests
-from lino.core import constants as ext_requests
+from lino.core import constants 
 
 import lino
 from lino.core import dbtables
@@ -106,7 +106,10 @@ class StoreField(object):
         return "%s '%s'" % (self.__class__.__name__, self.name)
         
     def column_names(self):
-        yield self.options['name']
+        #~ if not self.options.has_key('name'):
+            #~ raise Exception("20130719 %s has no option 'name'" % self)
+        #~ yield self.options['name']
+        yield self.name
         
     def value_from_object(self,obj,ar):
         return self.full_value_from_object(obj,ar)
@@ -212,7 +215,7 @@ class RelatedMixin(object):
         # but the full object this field refers to
         relto_model = self.get_rel_to(obj)
         if not relto_model:
-            logger.warning("%s get_rel_to returned None",self.field)
+            #~ logger.warning("%s get_rel_to returned None",self.field)
             return None
         try:
             return getattr(obj,self.name)
@@ -227,19 +230,19 @@ class ComboStoreField(StoreField):
     
     def as_js(self,name):
         s = StoreField.as_js(self,name)
-        #~ s += "," + repr(self.field.name+ext_requests.CHOICES_HIDDEN_SUFFIX)
-        s += ", '%s'" % (name+ext_requests.CHOICES_HIDDEN_SUFFIX)
+        #~ s += "," + repr(self.field.name+constants.CHOICES_HIDDEN_SUFFIX)
+        s += ", '%s'" % (name+constants.CHOICES_HIDDEN_SUFFIX)
         return s 
         
     def column_names(self):
         #~ yield self.options['name']
-        #~ yield self.options['name'] + ext_requests.CHOICES_HIDDEN_SUFFIX
+        #~ yield self.options['name'] + constants.CHOICES_HIDDEN_SUFFIX
         yield self.name
-        yield self.name + ext_requests.CHOICES_HIDDEN_SUFFIX
+        yield self.name + constants.CHOICES_HIDDEN_SUFFIX
         
     def extract_form_data(self,post_data):
         #~ logger.info("20130128 ComboStoreField.extract_form_data %s",self.name)
-        return post_data.get(self.name+ext_requests.CHOICES_HIDDEN_SUFFIX,None)
+        return post_data.get(self.name+constants.CHOICES_HIDDEN_SUFFIX,None)
         
     #~ def obj2list(self,request,obj):
     def value2list(self,ar,v,l,row):
@@ -250,7 +253,7 @@ class ComboStoreField(StoreField):
     def value2dict(self,v,d,row):
         value,text = self.get_value_text(v,row)
         d[self.name] = text
-        d[self.name + ext_requests.CHOICES_HIDDEN_SUFFIX] = value
+        d[self.name + constants.CHOICES_HIDDEN_SUFFIX] = value
         
     def get_value_text(self,v,obj):
         #~ v = self.full_value_from_object(None,obj)
@@ -395,18 +398,6 @@ class PasswordStoreField(StoreField):
             return "*" * len(v)
         return v
         
-class GenericForeignKeyField(StoreField):
-        
-    def full_value_from_object(self,obj,ar):
-        return getattr(obj,self.name,None)
-        #~ owner = getattr(obj,self.name)
-        #~ if owner is None: 
-            #~ # owner_id = getattr(obj,self.field.fk_field)
-            #~ # if owner_id is None:
-                #~ # return ''
-            #~ return ''
-        #~ return ar.href_to(owner)
-  
 class SpecialStoreField(StoreField):
     field = None 
     name = None
@@ -599,7 +590,7 @@ class BooleanStoreField(StoreField):
         Ext.ensible CalendarPanel sends boolean values as 
         """
         #~ print "20110717 parse_form_value", self.field.name, v, obj
-        return ext_requests.parse_boolean(v)
+        return constants.parse_boolean(v)
 
         
     def format_value(self,ar,v):
@@ -612,6 +603,51 @@ class DisplayStoreField(StoreField):
         #~ return E.td(v,**cellattrs)
   
 
+#~ class GenericForeignKeyField(ForeignKeyStoreField):
+class GenericForeignKeyField(DisplayStoreField):
+    
+    #~ def get_rel_to(self,obj):
+        #~ ct = getattr(obj,self.field.ct_field)
+        #~ return ct.model_class()
+        
+    def full_value_from_object(self,obj,ar):
+        v = getattr(obj,self.name,None)
+        #~ logger.info("20130611 full_value_from_object() %s",v)
+        if v is None: return ''
+        if ar is None: return unicode(v)
+        if ar.renderer is None: return unicode(v)
+        return ar.href_to(v)
+        #~ owner = getattr(obj,self.name)
+        #~ if owner is None: 
+            #~ # owner_id = getattr(obj,self.field.fk_field)
+            #~ # if owner_id is None:
+                #~ # return ''
+            #~ return ''
+        #~ return ar.href_to(owner)
+  
+
+class unused_GenericForeignKeyField(StoreField):
+        
+    def full_value_from_object(self,obj,ar):
+        v = getattr(obj,self.name,None)
+        #~ logger.info("full_value_from_object() %s",v)
+        return v
+        #~ owner = getattr(obj,self.name)
+        #~ if owner is None: 
+            #~ # owner_id = getattr(obj,self.field.fk_field)
+            #~ # if owner_id is None:
+                #~ # return ''
+            #~ return ''
+        #~ return ar.href_to(owner)
+  
+    def value2list(self,ar,v,l,row):
+        return l.append(unicode(v))
+        
+    def value2dict(self,v,d,row):
+        d[self.name] = unicode(v)
+
+
+
 class DecimalStoreField(StoreField):
     #~ def __init__(self,field,name,**kw):
         #~ kw['type'] = 'float'
@@ -1150,10 +1186,11 @@ class Store(BaseStore):
             for fld in self.list_fields:
                 v = fld.full_value_from_object(row,request)
                 #~ if fld.name == 'person__age':
-                    #~ logger.info("20120406 Store.row2list %s -> %s", fld, v)
+                #~ logger.info("20120406 Store.row2list %s -> %s", fld, v)
                 fld.value2list(request,v,l,row)
                 #~ if fld.name == 'person__age':
                     #~ logger.info("20120406 Store.row2list %s -> %s", fld, l)
+        #~ logger.info("20130611 Store row2list() --> %r", l)
         return l
       
     def row2dict(self,ar,row,fields=None,**d):
