@@ -404,6 +404,7 @@ class AdminIndex(View):
     Similar to PlainIndex
     """
     def get(self, request, *args, **kw):
+        #~ logger.info("20130719 AdminIndex")
         settings.SITE.startup()
         ui = settings.SITE.ui
         if settings.SITE.user_model is not None:
@@ -415,12 +416,16 @@ class AdminIndex(View):
 
 class MainHtml(View):
     def get(self, request, *args, **kw):
+        #~ logger.info("20130719 MainHtml")
         settings.SITE.startup()
         ui = settings.SITE.ui
         rv = ui.success(html=settings.SITE.get_main_html(request))
         return ui.action_response(rv)
         
 class Authenticate(View):
+    """
+    This view is being used only when not remote http auth
+    """
   
     def get(self, request, *args, **kw):
         action_name = request.GET.get(ext_requests.URL_PARAM_ACTION_NAME)
@@ -478,7 +483,7 @@ class Callbacks(View):
 if settings.SITE.user_model and settings.SITE.use_tinymce:
   
     from jinja2 import Template as JinjaTemplate
-    from lino.ui.models import TextFieldTemplate
+    TextFieldTemplate = settings.SITE.modules.system.TextFieldTemplate
 
     class Templates(View):
       """
@@ -534,35 +539,39 @@ if settings.SITE.user_model and settings.SITE.use_tinymce:
 
 
 
-def choices_for_field(request,rpt,field):
+def choices_for_field(request,actor,field):
+    """
+    Return the choices for the given field and the given web request 
+    (whose requesting actor has already been identified and is given 
+    as `actor`).
+    """
     #~ logger.info("20120202 %r",field)
     chooser = choosers.get_for_field(field)
     if chooser:
         #~ logger.info('20120710 choices_view() : has chooser')
-        qs = chooser.get_request_choices(request,rpt)
-        #~ qs = list(chooser.get_request_choices(ar,rpt))
+        qs = chooser.get_request_choices(request,actor)
+        #~ qs = list(chooser.get_request_choices(ar,actor))
         #~ logger.info("20120213 %s",qs)
         #~ if qs is None:
             #~ qs = []
         assert isiterable(qs), \
               "%s.%s_choices() returned %r which is not iterable." % (
-              rpt.model,field.name,qs)
+              actor.model,field.name,qs)
         if chooser.simple_values:
             def row2dict(obj,d):
                 d[ext_requests.CHOICES_TEXT_FIELD] = unicode(obj)
-                #~ 20130117 : 'int' object has no attribute 'get_choices_text'
                 d[ext_requests.CHOICES_VALUE_FIELD] = obj
                 return d
         elif chooser.instance_values:
             # same code as for ForeignKey
             def row2dict(obj,d):
-                d[ext_requests.CHOICES_TEXT_FIELD] = obj.get_choices_text(request,rpt,field)
+                #~ d[ext_requests.CHOICES_TEXT_FIELD] = obj.get_choices_text(request,actor,field)
+                d[ext_requests.CHOICES_TEXT_FIELD] = actor.get_choices_text(obj,request,field)
                 d[ext_requests.CHOICES_VALUE_FIELD] = obj.pk
                 return d
-        else:
+        else: # values are (value,text) tuples
             def row2dict(obj,d):
                 d[ext_requests.CHOICES_TEXT_FIELD] = unicode(obj[1])
-                #~ d[ext_requests.CHOICES_TEXT_FIELD] = obj[1].get_choices_text(request,rpt,field)
                 d[ext_requests.CHOICES_VALUE_FIELD] = obj[0]
                 return d
     elif field.choices:
@@ -572,7 +581,8 @@ def choices_for_field(request,rpt,field):
                 d[ext_requests.CHOICES_TEXT_FIELD] = unicode(obj[1])
                 d[ext_requests.CHOICES_VALUE_FIELD] = obj[0]
             else:
-                d[ext_requests.CHOICES_TEXT_FIELD] = obj.get_choices_text(request,rpt,field)
+                #~ d[ext_requests.CHOICES_TEXT_FIELD] = obj.get_choices_text(request,actor,field)
+                d[ext_requests.CHOICES_TEXT_FIELD] = actor.get_choices_text(obj,request,field)
                 d[ext_requests.CHOICES_VALUE_FIELD] = unicode(obj)
             return d
         
@@ -582,7 +592,8 @@ def choices_for_field(request,rpt,field):
         qs = t.request(request=request).data_iterator
         #~ logger.info('20120710 choices_view(FK) %s --> %s',t,qs)
         def row2dict(obj,d):
-            d[ext_requests.CHOICES_TEXT_FIELD] = obj.get_choices_text(request,rpt,field)
+            #~ d[ext_requests.CHOICES_TEXT_FIELD] = obj.get_choices_text(request,actor,field)
+            d[ext_requests.CHOICES_TEXT_FIELD] = actor.get_choices_text(obj,request,field)
             d[ext_requests.CHOICES_VALUE_FIELD] = obj.pk 
             return d
     else:
@@ -947,6 +958,13 @@ class ApiList(View):
             #~ ar.renderer = ui.ext_renderer
             #~ after_show = ar.get_status(ar.ui)
             after_show = ar.get_status(settings.SITE.ui)
+            
+            sp = request.GET.get(ext_requests.URL_PARAM_SHOW_PARAMS_PANEL,None)
+            if sp is not None: 
+                #~ after_show.update(show_params_panel=sp)
+                after_show.update(show_params_panel=ext_requests.parse_boolean(sp))
+            
+            
             if isinstance(ar.bound_action.action,actions.InsertRow):
                 elem = ar.create_instance()
                 #~ print 20120630
@@ -1074,7 +1092,7 @@ def plain_response(ui,request,tplname,context):
     return response
             
 
-  
+
 class PlainList(View):
   
     def get(self,request,app_label=None,actor=None):
