@@ -36,6 +36,8 @@ Documented classes and functions
 
 import os
 import logging
+from django.utils.importlib import import_module
+
 logger = logging.getLogger(__name__)
 
 
@@ -276,6 +278,21 @@ class UserProfiles(ChoiceList):
 
 
 #~ def default_required(): return dict(auth=True)
+class Requirements(object):
+    """
+    Not yet used. TODO: implement requirements as a class. 
+    - handle conversions (like accepting both list and string for `user_groups` ),
+    - implement loosen_requirements as __or__() 
+    - implement add_requirements as __and__() 
+    """
+    user_level = None
+    user_groups = None
+    states = None
+    allow = None
+    auth = True
+    owner = None
+    
+
 
 def make_permission_handler(*args,**kw):
     """
@@ -303,6 +320,14 @@ def make_permission_handler(*args,**kw):
         required to get the permission.
         The default value `None` means that no special user level is required.
         
+        When `user_groups` is not specified, 
+        then the profile's default level (`UserProfile.level`) 
+        is being tested, otherwise the userlevel for the group 
+        membership.
+        E.g. `dd.required(user_level='manager',user_groups='integ')` 
+        will pass when `profile.level` is "user" and `profile.integ_level` is "manager"
+        
+        
     `user_groups`
         List of strings naming the user groups for which membership is required 
         to get permission to view this Actor.
@@ -344,8 +369,7 @@ def make_view_permission_handler(*args,**kw):
     
 def make_view_permission_handler_(
     actor,readonly,debug_permissions,
-    user_level=None,user_groups=None,allow=None,auth=False,
-    owner=None,states=None):
+    user_level=None,user_groups=None,allow=None,auth=False,owner=None,states=None):
     #~ if states is not None:
         #~ logger.info("20121121 ignoring required states %s for %s",states,actor)
     #~ if owner is not None:
@@ -354,7 +378,7 @@ def make_view_permission_handler_(
         def allow(action,profile):
             return True
     #~ if settings.SITE.user_model is not None:
-    if True: # e.g. e.g. public readonly site
+    if True: # e.g. public readonly site
         if auth:
             allow_before_auth = allow
             def allow(action,profile):
@@ -362,20 +386,13 @@ def make_view_permission_handler_(
                     return False
                 return allow_before_auth(action,profile)
             
-        if user_level is not None:
-            user_level = getattr(UserLevels,user_level)
-            allow_user_level = allow
-            def allow(action,profile):
-                if profile.level < user_level:
-                    return False
-                return allow_user_level(action,profile)
-                
         if user_groups is not None:
             if isinstance(user_groups,basestring):
                 user_groups = user_groups.split()
             if user_level is None:
                 user_level = UserLevels.user
-                #~ raise Exception("20120621")
+            else:
+                user_level = getattr(UserLevels,user_level)
             for g in user_groups:
                 UserGroups.get_by_value(g) # raise Exception if no such group exists
                 #~ if not UserGroups.get_by_name(g):
@@ -387,8 +404,18 @@ def make_view_permission_handler_(
                     level = getattr(profile,g+'_level')
                     if level >= user_level:
                         return True
+                    #~ elif debug_permissions:
+                        #~ logger.info("20130704 level %r < %r",level,user_level)
                 return False
     
+        elif user_level is not None:
+            user_level = getattr(UserLevels,user_level)
+            allow_user_level = allow
+            def allow(action,profile):
+                if profile.level < user_level:
+                    return False
+                return allow_user_level(action,profile)
+                
     if not readonly:
         allow3 = allow
         def allow(action,profile):
@@ -413,7 +440,7 @@ def make_view_permission_handler_(
 
 def make_permission_handler_(
     elem,actor,readonly,debug_permissions,
-    user_level=None,user_groups=None,states=None,allow=None,owner=None,auth=False):
+    user_level=None,user_groups=None,allow=None,auth=False,owner=None,states=None):
         
     #~ if str(actor) == 'courses.PendingCourseRequests':
         #~ if allow is None: raise Exception("20130424")
@@ -427,7 +454,7 @@ def make_permission_handler_(
         def allow(action,user,obj,state):
             return True
     #~ if settings.SITE.user_model is not None:
-    if True: # e.g. e.g. public readonly site
+    if True: # e.g. public readonly site
         if auth:
             allow_before_auth = allow
             def allow(action,user,obj,state):
@@ -437,18 +464,6 @@ def make_permission_handler_(
                     return False
                 return allow_before_auth(action,user,obj,state)
             
-        if user_level is not None:
-            user_level = getattr(UserLevels,user_level)
-            allow_user_level = allow
-            def allow(action,user,obj,state):
-                #~ if user.profile.level is None or user.profile.level < user_level:
-                if user.profile.level < user_level:
-                    #~ print 20120715, user.profile.level
-                    #~ if action.action_name == 'wf7':
-                        #~ logger.info("20130424 allow_user_level returned False")
-                    return False
-                return allow_user_level(action,user,obj,state)
-                
         if owner is not None:
             allow_owner = allow
             def allow(action,user,obj,state):
@@ -463,7 +478,8 @@ def make_permission_handler_(
                 user_groups = user_groups.split()
             if user_level is None:
                 user_level = UserLevels.user
-                #~ raise Exception("20120621")
+            else:
+                user_level = getattr(UserLevels,user_level)
             for g in user_groups:
                 UserGroups.get_by_value(g) # raise Exception if no such group exists
                 #~ if not UserGroups.get_by_name(g):
@@ -480,6 +496,18 @@ def make_permission_handler_(
                         return True
                 return False
             
+        elif user_level is not None:
+            user_level = getattr(UserLevels,user_level)
+            allow_user_level = allow
+            def allow(action,user,obj,state):
+                #~ if user.profile.level is None or user.profile.level < user_level:
+                if user.profile.level < user_level:
+                    #~ print 20120715, user.profile.level
+                    #~ if action.action_name == 'wf7':
+                        #~ logger.info("20130424 allow_user_level returned False")
+                    return False
+                return allow_user_level(action,user,obj,state)
+                
     if states is not None:
         #~ if not isinstance(actor.workflow_state_field,choicelists.ChoiceListField):
         if actor.workflow_state_field is None:
@@ -550,6 +578,7 @@ class AnonymousUser(object):
     modified = None
     partner = None
     language = None
+    #~ id = None
     
     _instance = None
     
@@ -561,7 +590,8 @@ class AnonymousUser(object):
             try:
                 cls._instance.profile = UserProfiles.get_by_value(settings.SITE.anonymous_user_profile)
                 if cls._instance.profile.authenticated:
-                    raise Exception("20121121 profile specified by `anonymous_user_profile` is `authenticated`")
+                    #~ raise Exception("20121121 profile specified by `anonymous_user_profile` is `authenticated`")
+                    logger.warning("20121121 profile specified by `anonymous_user_profile` is `authenticated`")
             except KeyError:
                 raise Exception(
                     "Invalid value %r for `SITE.anonymous_user_profile`. Must be one of %s" % (
@@ -571,42 +601,7 @@ class AnonymousUser(object):
         
     def __str__(self):
         return self.username
-    
 
-
-class NOT_NEEDED:
-    pass
-    
-    
-def authenticate(username,password=NOT_NEEDED):
-    #~ print "20130515 authenticate %s,%s" % (username,password)
-
-    if not username:
-        return AnonymousUser.instance()
-        
-    """
-    20120110 : alicia hatte es geschafft, 
-    beim Anmelden ein Leerzeichen vor ihren Namen zu setzen. 
-    Apache ließ sie als " alicia" durch.
-    Und Lino legte brav einen neuen User " alicia" an.
-    """
-    username = username.strip()
-    
-    try:
-        user = settings.SITE.user_model.objects.get(username=username)
-        if user.profile is None:
-            #~ logger.info("20121127 user has no profile")
-            return None
-        if password != NOT_NEEDED:
-            if not user.check_password(password):
-                #~ logger.info("20121104 password mismatch")
-                return None
-        return user
-    except settings.SITE.user_model.DoesNotExist,e:
-        #~ logger.info("20121104 no username %r",username)
-        return None  
-    
-    
 class AuthMiddleWareBase(object):
     """
     Common base class for 
@@ -631,7 +626,37 @@ class AuthMiddleWareBase(object):
         
         self.on_login(request,user)
         
-        
+    class NOT_NEEDED:
+        pass
+
+    @classmethod
+    def authenticate(cls, username, password=NOT_NEEDED):
+        #~ print "20130515 authenticate %s,%s" % (username,password)
+
+        if not username:
+            return AnonymousUser.instance()
+
+        """
+        20120110 : Alicia once managed to add a space char in front of 
+        her username log in the login dialog. 
+        Apache let her in as " alicia".
+        """
+        username = username.strip()
+
+        try:
+            user = settings.SITE.user_model.objects.get(username=username)
+            if user.profile is None:
+                #~ logger.info("20121127 user has no profile")
+                return None
+            if password != cls.NOT_NEEDED:
+                if not user.check_password(password):
+                    #~ logger.info("20121104 password mismatch")
+                    return None
+            return user
+        except settings.SITE.user_model.DoesNotExist,e:
+            #~ logger.info("20121104 no username %r",username)
+            return None
+
             
             
     def on_login(self,request,user):
@@ -728,13 +753,13 @@ class RemoteUserMiddleware(AuthMiddleWareBase):
             #~ raise exceptions.PermissionDenied(msg)
             raise Exception("Using remote authentication, but no user credentials found.")
             
-        user = authenticate(username)
+        user = self.authenticate(username)
         
         if user is None:
             #~ logger.info("20130514 Unknown username %s from request %s",username, request)
             #~ raise Exception(
             #~ raise exceptions.PermissionDenied("Unknown or inactive username %r. Please contact your system administrator." 
-            logger.info("Unknown or inactive username %r.",username)
+            #~ logger.info("Unknown or inactive username %r.",username)
             raise exceptions.PermissionDenied()
               
         return user
@@ -749,7 +774,7 @@ class SessionUserMiddleware(AuthMiddleWareBase):
 
     def get_user_from_request(self, request):
       
-        user = authenticate(request.session.get('username'),
+        user = self.authenticate(request.session.get('username'),
             request.session.get('password'))
         
         if user is None:
@@ -770,3 +795,14 @@ class NoUserMiddleware(AuthMiddleWareBase):
         
         
         
+def get_auth_middleware():
+    if settings.SITE.auth_middleware is None:
+        return AuthMiddleWareBase
+    module, obj = settings.SITE.auth_middleware.rsplit('.', 1)
+    module = import_module(module)
+    return getattr(module, obj)
+
+def authenticate(*args, **kwargs):
+    middleware = get_auth_middleware()
+    return middleware.authenticate(*args, **kwargs)
+    
