@@ -36,7 +36,7 @@ from lino.utils.instantiator import make_converter
 #~ import lino
 #~ from lino.core import fields
 from lino.utils import get_class_attr
-from lino.ui import requests as ext_requests
+from lino.core import constants # as ext_requests
 
 class BaseChooser:
     pass
@@ -59,6 +59,7 @@ class Chooser(FieldChooser):
     simple_values = False
     instance_values = True
     force_selection = True
+    choice_display_method = None # not yet used. 
     #~ quick_search_fields = None
     #~ force_selection = True
     #~ on_quick_insert = None
@@ -70,7 +71,7 @@ class Chooser(FieldChooser):
         #~ self.field = model._meta.get_field(fldname)
         self.meth = meth
         if not isinstance(field,models.ForeignKey):
-            self.simple_values = getattr(meth,'simple_values',False)        
+            self.simple_values = getattr(meth,'simple_values',False)
             self.instance_values = getattr(meth,'instance_values',False)
             self.force_selection = getattr(meth,'force_selection',self.force_selection)
         #~ self.context_params = meth.func_code.co_varnames[1:meth.func_code.co_argcount]
@@ -106,6 +107,11 @@ class Chooser(FieldChooser):
         if hasattr(model,"create_%s_choice" % field.name):
             self.can_create_choice = True
             
+        #~ if hasattr(model,"get_%s_display" % field.name):
+        m = getattr(model,"%s_choice_display" % field.name,None)
+        if m is not None:
+            self.choice_display_method = m
+            
     def __str__(self):
         return "Chooser(%s.%s,%s)" % (
             self.model.__name__,self.field.name,
@@ -146,13 +152,13 @@ class Chooser(FieldChooser):
         
         # 20120202
         if tbl.master_field is not None:
-            mt = request.REQUEST.get(ext_requests.URL_PARAM_MASTER_TYPE)
+            mt = request.REQUEST.get(constants.URL_PARAM_MASTER_TYPE)
             try:
                 master = ContentType.objects.get(pk=mt).model_class()
             except ContentType.DoesNotExist,e:
                 pass
                 
-            pk = request.REQUEST.get(ext_requests.URL_PARAM_MASTER_PK,None)
+            pk = request.REQUEST.get(constants.URL_PARAM_MASTER_PK,None)
             if pk:
                 try:
                     kw[tbl.master_field.name] = master.objects.get(pk=pk)
