@@ -14,11 +14,18 @@ class LinoTestCase(TestCase):
     #~ default_environ = dict(DJANGO_SETTINGS_MODULE="lino.projects.std.settings")
     project_root = ROOTDIR
     
+class PackagesTests(LinoTestCase):
+    def test_01(self): self.run_packages_test(SETUP_INFO['packages'])
+
 class BlogTest(LinoTestCase):
     def test_20130316(self): self.run_simple_doctests('docs/blog/2013/0316.rst')
     def test_20130507(self): self.run_simple_doctests('docs/blog/2013/0507.rst')
     def test_20130508(self): self.run_simple_doctests('docs/blog/2013/0508.rst')
     #~ def test_20130513(self): self.run_simple_doctests('docs/blog/2013/0513.rst')
+    #~ def test_20130622(self): self.run_simple_doctests('docs/blog/2013/0622.rst')
+    #~ def test_20130714(self): self.run_simple_doctests('docs/blog/2013/0714.rst')
+    def test_20130716(self): self.run_simple_doctests('docs/blog/2013/0716.rst')
+    def test_20130719(self): self.run_simple_doctests('docs/blog/2013/0719.rst')
     
 class DocsTests(LinoTestCase):
 
@@ -33,7 +40,8 @@ class DocsTests(LinoTestCase):
 class UtilsTests(LinoTestCase):
     def test_01(self): self.run_simple_doctests('lino/utils/__init__.py')
     def test_02(self): self.run_simple_doctests('lino/utils/html2odf.py')
-    def test_04(self): self.run_simple_doctests('lino/utils/xmlgen/html.py')
+    def test_xmlgen_html(self): self.run_simple_doctests('lino/utils/xmlgen/html.py')
+    def test_xmlgen_sepa(self): self.run_simple_doctests('lino/utils/xmlgen/sepa.py')
     def test_05(self): self.run_simple_doctests('lino/utils/memo.py')
     def test_06(self): self.run_simple_doctests('lino/utils/html2xhtml.py')
     def test_07(self): self.run_simple_doctests('lino/utils/demonames.py')
@@ -47,13 +55,11 @@ class UtilsTests(LinoTestCase):
     def test_24(self): self.run_simple_doctests('lino/modlib/ledger/utils.py')
     def test_25(self): self.run_simple_doctests('lino/modlib/accounts/utils.py')
     def test_26(self): self.run_simple_doctests('lino/modlib/contacts/utils.py')
+    def test_cal_utils(self): self.run_simple_doctests('lino/modlib/cal/utils.py')
 
-class PackagesTests(LinoTestCase):
-    """
-    Runs certain tests related to packaging.
-    """
-    def test_01(self): self.run_packages_test(SETUP_INFO['packages'])
-
+class I18nTests(LinoTestCase):
+    def test_i18n(self): self.run_simple_doctests('docs/tested/test_i18n.rst')
+    
 class CosiTests(LinoTestCase):
     def test_cosi(self):      self.run_django_admin_test("lino.projects.cosi.settings") # covered by docs/tutorials/quickstart
     def test_cosi_demo(self): self.run_simple_doctests('docs/tested/test_cosi_demo.rst')
@@ -64,7 +70,7 @@ class ProjectsTests(LinoTestCase):
     def test_presto(self): self.run_django_admin_test("lino.projects.presto.test_settings") 
     def test_belref(self): self.run_django_admin_test("lino.projects.belref.settings") 
     def test_babel_tutorial(self): self.run_django_admin_test("lino.projects.babel_tutorial.settings") 
-    def test_homeworkschool(self): self.run_django_admin_test("lino.projects.homeworkschool.settings") 
+    def test_homeworkschool(self): self.run_django_admin_test("lino.projects.homeworkschool.settings.demo") 
     def test_min1(self): self.run_django_admin_test("lino.projects.min1.settings") 
     def test_min2(self): self.run_django_admin_test("lino.projects.min2.settings") 
     
